@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2023-2024 Intel Corporation
+ * Copyright (C) 2023-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -66,6 +66,12 @@ zexCounterBasedEventCreate2(ze_context_handle_t hContext, ze_device_handle_t hDe
         return ZE_RESULT_ERROR_INVALID_ARGUMENT;
     }
 
+    auto signalScope = desc->signalScope;
+
+    if (NEO::debugManager.flags.MitigateHostVisibleSignal.get()) {
+        signalScope &= ~ZE_EVENT_SCOPE_FLAG_HOST;
+    }
+
     EventDescriptor eventDescriptor = {
         nullptr,                           // eventPoolAllocation
         desc->pNext,                       // extensions
@@ -74,17 +80,23 @@ zexCounterBasedEventCreate2(ze_context_handle_t hContext, ze_device_handle_t hDe
         1,                                 // maxPacketsCount
         inputCbFlags,                      // counterBasedFlags
         0,                                 // index
-        desc->signalScope,                 // signalScope
+        signalScope,                       // signalScope
         desc->waitScope,                   // waitScope
         timestampFlag,                     // timestampPool
-        mappedTimestampFlag,               // kerneMappedTsPoolFlag
+        mappedTimestampFlag,               // kernelMappedTsPoolFlag
         false,                             // importedIpcPool
         ipcFlag,                           // ipcPool
     };
 
     ze_result_t result = ZE_RESULT_SUCCESS;
 
-    *phEvent = device->getL0GfxCoreHelper().createStandaloneEvent(eventDescriptor, device, result);
+    auto l0Event = device->getL0GfxCoreHelper().createStandaloneEvent(eventDescriptor, device, result);
+
+    if (signalScope ^ desc->signalScope) {
+        l0Event->setMitigateHostVisibleSignal();
+    }
+
+    *phEvent = l0Event;
 
     return result;
 }
@@ -97,12 +109,12 @@ zexCounterBasedEventCreate(ze_context_handle_t hContext, ze_device_handle_t hDev
         return ZE_RESULT_ERROR_INVALID_ARGUMENT;
     }
 
-    zex_counter_based_event_external_sync_alloc_properties_t externalSyncAllocProperties = {ZEX_STRUCTURE_COUTER_BASED_EVENT_EXTERNAL_SYNC_ALLOC_PROPERTIES}; // NOLINT(clang-analyzer-optin.core.EnumCastOutOfRange), NEO-12901
+    zex_counter_based_event_external_sync_alloc_properties_t externalSyncAllocProperties = {ZEX_STRUCTURE_COUNTER_BASED_EVENT_EXTERNAL_SYNC_ALLOC_PROPERTIES}; // NOLINT(clang-analyzer-optin.core.EnumCastOutOfRange), NEO-12901
     externalSyncAllocProperties.completionValue = completionValue;
     externalSyncAllocProperties.deviceAddress = deviceAddress;
     externalSyncAllocProperties.hostAddress = hostAddress;
 
-    zex_counter_based_event_desc_t counterBasedDesc = {ZEX_STRUCTURE_COUTER_BASED_EVENT_DESC}; // NOLINT(clang-analyzer-optin.core.EnumCastOutOfRange), NEO-12901
+    zex_counter_based_event_desc_t counterBasedDesc = {ZEX_STRUCTURE_COUNTER_BASED_EVENT_DESC}; // NOLINT(clang-analyzer-optin.core.EnumCastOutOfRange), NEO-12901
     counterBasedDesc.flags = counterBasedFlags;
     counterBasedDesc.signalScope = desc->signal;
     counterBasedDesc.waitScope = desc->wait;
