@@ -17,7 +17,8 @@
 namespace L0 {
 
 BuiltinFunctionsLibImpl::BuiltinData::~BuiltinData() {
-    func.reset();
+    func->destroy();
+    func.release();
 }
 BuiltinFunctionsLibImpl::BuiltinData::BuiltinData() = default;
 BuiltinFunctionsLibImpl::BuiltinData::BuiltinData(Module *module, std::unique_ptr<L0::Kernel> &&ker) : module(module), func(std::move(ker)) {}
@@ -179,6 +180,14 @@ void BuiltinFunctionsLibImpl::initBuiltinImageKernel(ImageBuiltin func) {
         builtinName = "CopyBufferToImage3d4BytesStateless";
         builtin = NEO::EBuiltInOps::copyBufferToImage3dHeapless;
         break;
+    case ImageBuiltin::copyBufferToImage3d3To4Bytes:
+        builtinName = "CopyBufferToImage3d3To4Bytes";
+        builtin = NEO::EBuiltInOps::copyBufferToImage3d;
+        break;
+    case ImageBuiltin::copyBufferToImage3d3To4BytesHeapless:
+        builtinName = "CopyBufferToImage3d3To4BytesStateless";
+        builtin = NEO::EBuiltInOps::copyBufferToImage3dHeapless;
+        break;
     case ImageBuiltin::copyBufferToImage3d8Bytes:
         builtinName = "CopyBufferToImage3d8Bytes";
         builtin = NEO::EBuiltInOps::copyBufferToImage3d;
@@ -187,6 +196,14 @@ void BuiltinFunctionsLibImpl::initBuiltinImageKernel(ImageBuiltin func) {
         builtinName = "CopyBufferToImage3d8BytesStateless";
         builtin = NEO::EBuiltInOps::copyBufferToImage3dHeapless;
         break;
+    case ImageBuiltin::copyBufferToImage3d6To8Bytes:
+        builtinName = "CopyBufferToImage3d6To8Bytes";
+        builtin = NEO::EBuiltInOps::copyBufferToImage3d;
+        break;
+    case ImageBuiltin::copyBufferToImage3d6To8BytesHeapless:
+        builtinName = "CopyBufferToImage3d6To8BytesStateless";
+        builtin = NEO::EBuiltInOps::copyBufferToImage3dHeapless;
+        break;
     case ImageBuiltin::copyBufferToImage3dBytes:
         builtinName = "CopyBufferToImage3dBytes";
         builtin = NEO::EBuiltInOps::copyBufferToImage3d;
@@ -227,6 +244,14 @@ void BuiltinFunctionsLibImpl::initBuiltinImageKernel(ImageBuiltin func) {
         builtinName = "CopyImage3dToBuffer4BytesStateless";
         builtin = NEO::EBuiltInOps::copyImage3dToBufferHeapless;
         break;
+    case ImageBuiltin::copyImage3dToBuffer4To3Bytes:
+        builtinName = "CopyImage3dToBuffer4To3Bytes";
+        builtin = NEO::EBuiltInOps::copyImage3dToBuffer;
+        break;
+    case ImageBuiltin::copyImage3dToBuffer4To3BytesHeapless:
+        builtinName = "CopyImage3dToBuffer4To3BytesStateless";
+        builtin = NEO::EBuiltInOps::copyImage3dToBufferHeapless;
+        break;
     case ImageBuiltin::copyImage3dToBuffer6Bytes:
         builtinName = "CopyImage3dToBuffer6Bytes";
         builtin = NEO::EBuiltInOps::copyImage3dToBuffer;
@@ -243,6 +268,14 @@ void BuiltinFunctionsLibImpl::initBuiltinImageKernel(ImageBuiltin func) {
         builtinName = "CopyImage3dToBuffer8BytesStateless";
         builtin = NEO::EBuiltInOps::copyImage3dToBufferHeapless;
         break;
+    case ImageBuiltin::copyImage3dToBuffer8To6Bytes:
+        builtinName = "CopyImage3dToBuffer8To6Bytes";
+        builtin = NEO::EBuiltInOps::copyImage3dToBuffer;
+        break;
+    case ImageBuiltin::copyImage3dToBuffer8To6BytesHeapless:
+        builtinName = "CopyImage3dToBuffer8To6BytesStateless";
+        builtin = NEO::EBuiltInOps::copyImage3dToBufferHeapless;
+        break;
     case ImageBuiltin::copyImage3dToBufferBytes:
         builtinName = "CopyImage3dToBufferBytes";
         builtin = NEO::EBuiltInOps::copyImage3dToBuffer;
