@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2024 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -53,8 +53,6 @@ void DriverImp::initialize(ze_result_t *result) {
         envReader.getSetting("ZE_ENABLE_PCI_ID_DEVICE_ORDER", false);
     envVariables.fp64Emulation =
         envReader.getSetting("NEO_FP64_EMULATION", false);
-    envVariables.deviceHierarchyMode =
-        envReader.getSetting("ZE_FLAT_DEVICE_HIERARCHY", std::string(NEO::deviceHierarchyUnk));
 
     auto executionEnvironment = new NEO::ExecutionEnvironment();
     UNRECOVERABLE_IF(nullptr == executionEnvironment);
@@ -159,7 +157,6 @@ ze_result_t initDriver() {
         std::lock_guard<std::mutex> lock(driverInitMutex);
 
         if (Driver::get()->getPid() != pid) {
-            ze_result_t result;
             Driver::get()->initialize(&result);
         }
     }
