@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2024 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -210,9 +210,17 @@ void EventPool::initializeSizeParameters(uint32_t numDevices, ze_device_handle_t
         eventPackets = driver.getEventMaxPacketCount(numDevices, deviceHandles);
         maxKernelCount = driver.getEventMaxKernelCount(numDevices, deviceHandles);
     }
-    setEventSize(static_cast<uint32_t>(alignUp(eventPackets * gfxCoreHelper.getSingleTimestampPacketSize(), eventAlignment)));
 
-    eventPoolSize = alignUp<size_t>(this->numEvents * eventSize, MemoryConstants::pageSize64k);
+    const uint32_t minimalPacketCount = isEventPoolTimestampFlagSet() ? 2 : 1;
+
+    auto eventSize = std::max(eventPackets, minimalPacketCount) * gfxCoreHelper.getSingleTimestampPacketSize();
+    if (eventPoolFlags & ZE_EVENT_POOL_FLAG_KERNEL_MAPPED_TIMESTAMP) {
+        eventSize += sizeof(NEO::TimeStampData);
+    }
+
+    setEventSize(static_cast<uint32_t>(alignUp(eventSize, eventAlignment)));
+
+    eventPoolSize = alignUp<size_t>(this->numEvents * this->eventSize, MemoryConstants::pageSize64k);
 }
 
 EventPool *EventPool::create(DriverHandle *driver, Context *context, uint32_t numDevices, ze_device_handle_t *deviceHandles, const ze_event_pool_desc_t *desc, ze_result_t &result) {
@@ -311,7 +319,7 @@ ze_result_t Event::openCounterBasedIpcHandle(const IpcCounterBasedEventData &ipc
         ipcData.signalScopeFlags,          // signalScope
         ipcData.waitScopeFlags,            // waitScope
         false,                             // timestampPool
-        false,                             // kerneMappedTsPoolFlag
+        false,                             // kernelMappedTsPoolFlag
         true,                              // importedIpcPool
         false,                             // ipcPool
     };
@@ -327,7 +335,7 @@ ze_result_t Event::openCounterBasedIpcHandle(const IpcCounterBasedEventData &ipc
 }
 
 ze_result_t Event::getCounterBasedIpcHandle(IpcCounterBasedEventData &ipcData) {
-    if (!this->isSharableCouterBased) {
+    if (!this->isSharableCounterBased) {
         return ZE_RESULT_ERROR_UNSUPPORTED_FEATURE;
     }
 
@@ -385,6 +393,7 @@ ze_result_t EventPool::getIpcHandle(ze_ipc_event_pool_handle_t *ipcHandle) {
     poolData.isImplicitScalingCapable = this->isImplicitScalingCapable;
     poolData.maxEventPackets = this->getEventMaxPackets();
     poolData.numDevices = static_cast<uint32_t>(this->devices.size());
+    poolData.isEventPoolKernelMappedTsFlagSet = this->isEventPoolKernelMappedTsFlagSet();
 
     auto memoryManager = this->context->getDriverHandle()->getMemoryManager();
     auto allocation = this->eventPoolAllocations->getDefaultGraphicsAllocation();
@@ -402,6 +411,9 @@ ze_result_t EventPool::openEventPoolIpcHandle(const ze_ipc_event_pool_handle_t &
     const IpcEventPoolData &poolData = *reinterpret_cast<const IpcEventPoolData *>(ipcEventPoolHandle.data);
 
     ze_event_pool_desc_t desc = {ZE_STRUCTURE_TYPE_EVENT_POOL_DESC};
+    if (poolData.isEventPoolKernelMappedTsFlagSet) {
+        desc.flags |= ZE_EVENT_POOL_FLAG_KERNEL_MAPPED_TIMESTAMP;
+    }
     desc.count = static_cast<uint32_t>(poolData.numEvents);
     auto eventPool = std::make_unique<EventPool>(&desc);
     eventPool->isDeviceEventPoolAllocation = poolData.isDeviceEventPoolAllocation;
@@ -640,10 +652,11 @@ void Event::unsetCmdQueue() {
 }
 
 void Event::setReferenceTs(uint64_t currentCpuTimeStamp) {
+    NEO::TimeStampData *referenceTs = static_cast<NEO::TimeStampData *>(ptrOffset(getHostAddress(), maxPacketCount * singlePacketSize));
     const auto recalculate =
-        (currentCpuTimeStamp - referenceTs.cpuTimeinNS) > timestampRefreshIntervalInNanoSec;
-    if (referenceTs.cpuTimeinNS == 0 || recalculate) {
-        device->getNEODevice()->getOSTime()->getGpuCpuTime(&referenceTs, true);
+        (currentCpuTimeStamp - referenceTs->cpuTimeinNS) > timestampRefreshIntervalInNanoSec;
+    if (referenceTs->cpuTimeinNS == 0 || recalculate) {
+        device->getNEODevice()->getOSTime()->getGpuCpuTime(referenceTs, true);
     }
 }
 
@@ -680,7 +693,7 @@ ze_result_t Event::enableExtensions(const EventDescriptor &eventDescriptor) {
                 setExternalInterruptId(eventSyncModeDesc->externalInterruptId);
                 UNRECOVERABLE_IF(eventSyncModeDesc->externalInterruptId > 0 && eventDescriptor.eventPoolAllocation);
             }
-        } else if (extendedDesc->stype == ZEX_STRUCTURE_COUTER_BASED_EVENT_EXTERNAL_SYNC_ALLOC_PROPERTIES) {
+        } else if (extendedDesc->stype == ZEX_STRUCTURE_COUNTER_BASED_EVENT_EXTERNAL_SYNC_ALLOC_PROPERTIES) {
             auto externalSyncAllocProperties = reinterpret_cast<const zex_counter_based_event_external_sync_alloc_properties_t *>(extendedDesc);
 
             if (!externalSyncAllocProperties->deviceAddress || !externalSyncAllocProperties->hostAddress) {
