@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2024 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -7,6 +7,8 @@
 
 #pragma once
 #include "shared/source/helpers/common_types.h"
+#include "shared/source/helpers/constants.h"
+#include "shared/source/helpers/ptr_math.h"
 #include "shared/source/helpers/timestamp_packet_constants.h"
 #include "shared/source/helpers/timestamp_packet_container.h"
 #include "shared/source/memory_manager/multi_graphics_allocation.h"
@@ -60,6 +62,7 @@ struct IpcEventPoolData {
     bool isDeviceEventPoolAllocation = false;
     bool isHostVisibleEventPoolAllocation = false;
     bool isImplicitScalingCapable = false;
+    bool isEventPoolKernelMappedTsFlagSet = false;
 };
 
 struct IpcCounterBasedEventData {
@@ -94,7 +97,7 @@ struct EventDescriptor {
     uint32_t signalScope = 0;
     uint32_t waitScope = 0;
     bool timestampPool = false;
-    bool kerneMappedTsPoolFlag = false;
+    bool kernelMappedTsPoolFlag = false;
     bool importedIpcPool = false;
     bool ipcPool = false;
 };
@@ -302,11 +305,11 @@ struct Event : _ze_event_handle_t {
     uint32_t getInOrderAllocationOffset() const { return inOrderAllocationOffset; }
     void setLatestUsedCmdQueue(CommandQueue *newCmdQ);
     NEO::TimeStampData *peekReferenceTs() {
-        return &referenceTs;
+        return static_cast<NEO::TimeStampData *>(ptrOffset(getHostAddress(), getMaxPacketsCount() * getSinglePacketSize()));
     }
     void setReferenceTs(uint64_t currentCpuTimeStamp);
     const CommandQueue *getLatestUsedCmdQueue() const { return latestUsedCmdQueue; }
-    bool hasKerneMappedTsCapability = false;
+    bool hasKernelMappedTsCapability = false;
     std::shared_ptr<NEO::InOrderExecInfo> &getInOrderExecInfo() { return inOrderExecInfo; }
     void enableKmdWaitMode() { kmdWaitMode = true; }
     void enableInterruptMode() { interruptMode = true; }
@@ -327,6 +330,10 @@ struct Event : _ze_event_handle_t {
 
     bool isIpcImported() const { return isFromIpcPool; }
 
+    void setMitigateHostVisibleSignal() {
+        this->mitigateHostVisibleSignal = true;
+    }
+
     virtual ze_result_t hostEventSetValue(State eventState) = 0;
 
   protected:
@@ -343,12 +350,11 @@ struct Event : _ze_event_handle_t {
     uint64_t globalEndTS = 1;
     uint64_t contextStartTS = 1;
     uint64_t contextEndTS = 1;
-    NEO::TimeStampData referenceTs{};
 
     uint64_t inOrderExecSignalValue = 0;
     uint32_t inOrderAllocationOffset = 0;
 
-    std::chrono::microseconds gpuHangCheckPeriod{500'000};
+    std::chrono::microseconds gpuHangCheckPeriod{CommonConstants::gpuHangCheckTimeInUS};
     std::bitset<EventPacketsCount::maxKernelSplit> l3FlushAppliedOnKernel;
 
     size_t contextStartOffset = 0u;
@@ -397,7 +403,8 @@ struct Event : _ze_event_handle_t {
     bool isFromIpcPool = false;
     bool kmdWaitMode = false;
     bool interruptMode = false;
-    bool isSharableCouterBased = false;
+    bool isSharableCounterBased = false;
+    bool mitigateHostVisibleSignal = false;
     uint64_t timestampRefreshIntervalInNanoSec = 0;
 };
 
@@ -440,7 +447,7 @@ struct EventPool : _ze_event_pool_handle_t {
         return false;
     }
 
-    bool isEventPoolKerneMappedTsFlagSet() const {
+    bool isEventPoolKernelMappedTsFlagSet() const {
         if (eventPoolFlags & ZE_EVENT_POOL_FLAG_KERNEL_MAPPED_TIMESTAMP) {
             return true;
         }
