@@ -79,7 +79,7 @@ struct EventImp : public Event {
     void copyDataToEventAlloc(void *dstHostAddr, uint64_t dstGpuVa, size_t copySize, const void *copyData);
     void copyTbxData(uint64_t dstGpuVa, size_t copySize);
     bool isTimestampPopulated() const { return (contextEndTS != Event::STATE_CLEARED || globalEndTS != Event::STATE_CLEARED); }
-    void synchronizeCounterBasedTimestampCompletionWithTimeout();
+    void synchronizeTimestampCompletionWithTimeout();
 };
 
 } // namespace L0
