@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2022 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -7,6 +7,9 @@
 
 #pragma once
 
+#include "shared/source/command_stream/task_count_helper.h"
+#include "shared/source/helpers/constants.h"
+
 #include <level_zero/ze_api.h>
 
 #include <chrono>
@@ -37,9 +40,9 @@ struct Fence : _ze_fence_handle_t {
   protected:
     Fence(CommandQueueImp *cmdQueueImp) : cmdQueue(cmdQueueImp) {}
 
-    std::chrono::microseconds gpuHangCheckPeriod{500'000};
+    std::chrono::microseconds gpuHangCheckPeriod{CommonConstants::gpuHangCheckTimeInUS};
     CommandQueueImp *cmdQueue;
-    uint32_t taskCount = 0;
+    TaskCountType taskCount = 0;
 };
 
 } // namespace L0
