@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2023 Intel Corporation
+ * Copyright (C) 2020-2024 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -26,6 +26,7 @@ struct ImageImp : public Image, NEO::NonCopyableOrMovableClass {
     ~ImageImp() override;
 
     NEO::GraphicsAllocation *getAllocation() override { return allocation; }
+    NEO::GraphicsAllocation *getImplicitArgsAllocation() override { return implicitArgsAllocation; }
     NEO::ImageInfo getImageInfo() override { return imgInfo; }
     ze_image_desc_t getImageDesc() override {
         return imageFormatDesc;
@@ -45,15 +46,31 @@ struct ImageImp : public Image, NEO::NonCopyableOrMovableClass {
         return sourceImageFormatDesc.has_value();
     }
 
+    bool isMimickedImage() override {
+        return mimickedImagefor3Ch;
+    }
+
+    void setMimickedImage(bool value) {
+        this->mimickedImagefor3Ch = value;
+    }
+
     ze_result_t allocateBindlessSlot() override;
     NEO::SurfaceStateInHeapInfo *getBindlessSlot() override;
+    ze_result_t getDeviceOffset(uint64_t *deviceOffset) override;
+    static size_t getRowPitchFor2dImage(Device *device, const NEO::ImageInfo &imgInfo);
 
   protected:
     Device *device = nullptr;
     NEO::ImageInfo imgInfo = {};
     NEO::GraphicsAllocation *allocation = nullptr;
+    NEO::GraphicsAllocation *implicitArgsAllocation = nullptr;
     ze_image_desc_t imageFormatDesc = {};
+    ze_sampler_desc_t samplerDesc = {};
     std::optional<ze_image_desc_t> sourceImageFormatDesc = {};
     std::unique_ptr<NEO::SurfaceStateInHeapInfo> bindlessInfo;
+    bool bindlessImage = false;
+    bool imageFromBuffer = false;
+    bool sampledImage = false;
+    bool mimickedImagefor3Ch = false;
 };
 } // namespace L0
