@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022-2024 Intel Corporation
+ * Copyright (C) 2022-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -8,6 +8,7 @@
 #include "zello_common.h"
 
 #include <bitset>
+#include <cstdlib>
 #include <cstring>
 #include <iomanip>
 #include <map>
@@ -65,6 +66,8 @@ bool isParamEnabled(int argc, char *argv[], const char *shortName, const char *l
 int getParamValue(int argc, char *argv[], const char *shortName, const char *longName, int defaultValue) {
     char **arg = &argv[1];
     char **argE = &argv[argc];
+    char *end = nullptr;
+    int base = 0;
 
     for (; arg != argE; ++arg) {
         if ((0 == strcmp(*arg, shortName)) || (0 == strcmp(*arg, longName))) {
@@ -72,7 +75,26 @@ int getParamValue(int argc, char *argv[], const char *shortName, const char *lon
             if (arg == argE) {
                 break;
             }
-            return atoi(*arg);
+            return static_cast<int>(strtol(*arg, &end, base));
+        }
+    }
+
+    return defaultValue;
+}
+
+uint32_t getParamValue(int argc, char *argv[], const char *shortName, const char *longName, uint32_t defaultValue) {
+    char **arg = &argv[1];
+    char **argE = &argv[argc];
+    char *end = nullptr;
+    int base = 0;
+
+    for (; arg != argE; ++arg) {
+        if ((0 == strcmp(*arg, shortName)) || (0 == strcmp(*arg, longName))) {
+            arg++;
+            if (arg == argE) {
+                break;
+            }
+            return static_cast<uint32_t>(strtoul(*arg, &end, base));
         }
     }
 
@@ -278,7 +300,6 @@ uint32_t getCommandQueueOrdinal(ze_device_handle_t &device, bool useCooperativeF
             break;
         }
     }
-    SUCCESS_OR_TERMINATE_BOOL(computeQueueGroupOrdinal != std::numeric_limits<uint32_t>::max());
     return computeQueueGroupOrdinal;
 }
 
@@ -394,7 +415,7 @@ bool counterBasedEventsExtensionPresent(ze_driver_handle_t &driverHandle) {
     std::string cbEventsExtensionString("ZE_experimental_event_pool_counter_based");
     ze_driver_extension_properties_t cbEventsExtension{};
 
-    strncpy(cbEventsExtension.name, cbEventsExtensionString.c_str(), cbEventsExtensionString.size());
+    std::snprintf(cbEventsExtension.name, sizeof(cbEventsExtension.name), "%s", cbEventsExtensionString.c_str());
     cbEventsExtension.version = ZE_EVENT_POOL_COUNTER_BASED_EXP_VERSION_CURRENT;
 
     std::vector<ze_driver_extension_properties_t> extensionsToCheck;
@@ -674,7 +695,7 @@ ze_result_t CommandHandler::destroy() {
 }
 
 TestBitMask getTestMask(int argc, char *argv[], uint32_t defaultValue) {
-    uint32_t value = static_cast<uint32_t>(getParamValue(argc, argv, "-m", "-mask", static_cast<int>(defaultValue)));
+    uint32_t value = getParamValue(argc, argv, "-m", "-mask", defaultValue);
     std::cout << "Test mask ";
     if (value != defaultValue) {
         std::cout << "override ";
