@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2024 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -126,10 +126,11 @@ struct MultiDeviceFixture {
     void tearDown();
 
     DebugManagerStateRestore restorer;
-    std::unique_ptr<Mock<L0::DriverHandleImp>> driverHandle;
+    std::unique_ptr<Mock<L0::DriverHandleImp>> driverHandle = std::make_unique<Mock<L0::DriverHandleImp>>();
     uint32_t numRootDevices = 4u;
     uint32_t numSubDevices = 2u;
     L0::ContextImp *context = nullptr;
+    NEO::DeviceHierarchyMode deviceHierarchyMode = NEO::DeviceHierarchyMode::composite;
 
     VariableBackup<_ze_driver_handle_t *> globalDriverHandleBackup{&globalDriverHandle};
     VariableBackup<uint32_t> driverCountBackup{&driverCount};
@@ -137,13 +138,22 @@ struct MultiDeviceFixture {
 
 struct MultiDeviceFixtureHierarchy : public MultiDeviceFixture {
     void setUp();
-    bool exposeSubDevices = true;
 };
 
-struct MultiDeviceFixtureCombinedHierarchy : public MultiDeviceFixture {
-    void setUp();
-    bool exposeSubDevices = true;
-    bool combinedHierarchy = true;
+struct MultiDeviceFixtureCompositeHierarchy : public MultiDeviceFixtureHierarchy {};
+
+struct MultiDeviceFixtureFlatHierarchy : public MultiDeviceFixtureHierarchy {
+    void setUp() {
+        this->deviceHierarchyMode = NEO::DeviceHierarchyMode::flat;
+        MultiDeviceFixtureHierarchy::setUp();
+    }
+};
+
+struct MultiDeviceFixtureCombinedHierarchy : public MultiDeviceFixtureHierarchy {
+    void setUp() {
+        this->deviceHierarchyMode = NEO::DeviceHierarchyMode::combined;
+        MultiDeviceFixtureHierarchy::setUp();
+    }
 };
 
 struct SingleRootMultiSubDeviceFixture : public MultiDeviceFixture {
