@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022-2024 Intel Corporation
+ * Copyright (C) 2022-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -33,7 +33,7 @@ struct InOrderCmdListFixture : public ::Test<ModuleFixture> {
         using EventImp<uint32_t>::Event::counterBasedMode;
         using EventImp<uint32_t>::Event::isFromIpcPool;
         using EventImp<uint32_t>::Event::counterBasedFlags;
-        using EventImp<uint32_t>::Event::isSharableCouterBased;
+        using EventImp<uint32_t>::Event::isSharableCounterBased;
         using EventImp<uint32_t>::eventPoolAllocation;
         using EventImp<uint32_t>::maxPacketCount;
         using EventImp<uint32_t>::inOrderExecInfo;
@@ -70,6 +70,7 @@ struct InOrderCmdListFixture : public ::Test<ModuleFixture> {
 
     void SetUp() override {
         NEO::debugManager.flags.ForcePreemptionMode.set(static_cast<int32_t>(NEO::PreemptionMode::Disabled));
+        NEO::debugManager.flags.ResolveDependenciesViaPipeControls.set(0u);
 
         ::Test<ModuleFixture>::SetUp();
         createKernel();
@@ -97,7 +98,7 @@ struct InOrderCmdListFixture : public ::Test<ModuleFixture> {
             0,                                 // signalScope
             0,                                 // waitScope
             false,                             // timestampPool
-            false,                             // kerneMappedTsPoolFlag
+            false,                             // kernelMappedTsPoolFlag
             false,                             // importedIpcPool
             false,                             // ipcPool
         };
