@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2023-2024 Intel Corporation
+ * Copyright (C) 2023-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -144,5 +144,13 @@ ze_result_t SysmanKmdInterfaceI915Upstream::getBusyAndTotalTicksConfigs(uint64_t
     return ZE_RESULT_ERROR_DEPENDENCY_UNAVAILABLE;
 }
 
+std::string SysmanKmdInterfaceI915Upstream::getGpuBindEntry() const {
+    return getGpuBindEntryI915();
+}
+
+std::string SysmanKmdInterfaceI915Upstream::getGpuUnBindEntry() const {
+    return getGpuUnBindEntryI915();
+}
+
 } // namespace Sysman
 } // namespace L0
