@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2023 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -11,6 +11,7 @@
 #include "shared/source/os_interface/device_factory.h"
 #include "shared/source/os_interface/linux/drm_neo.h"
 #include "shared/source/os_interface/os_interface.h"
+#include "shared/test/common/mocks/mock_device.h"
 
 #include "level_zero/core/source/driver/driver.h"
 #include "level_zero/core/test/unit_tests/fixtures/device_fixture.h"
@@ -58,7 +59,7 @@ class SysmanDeviceFixture : public DeviceFixture, public ::testing::Test {
         }
         DeviceFixture::setUp();
         neoDevice->getExecutionEnvironment()->rootDeviceEnvironments[device->getRootDeviceIndex()]->osInterface = std::make_unique<NEO::OSInterface>();
-        auto &osInterface = device->getOsInterface();
+        auto &osInterface = *device->getOsInterface();
         osInterface.setDriverModel(std::make_unique<SysmanMockDrm>(const_cast<NEO::RootDeviceEnvironment &>(neoDevice->getRootDeviceEnvironment())));
         setenv("ZES_ENABLE_SYSMAN", "1", 1);
         device->setSysmanHandle(new SysmanDeviceImp(device->toHandle()));
@@ -74,8 +75,8 @@ class SysmanDeviceFixture : public DeviceFixture, public ::testing::Test {
         pLinuxSysmanImp->pSysfsAccess = pSysfsAccess;
         pLinuxSysmanImp->pProcfsAccess = pProcfsAccess;
 
-        if (GlobalOsSysmanDriver == nullptr) {
-            GlobalOsSysmanDriver = L0::OsSysmanDriver::create();
+        if (globalOsSysmanDriver == nullptr) {
+            globalOsSysmanDriver = L0::OsSysmanDriver::create();
         }
 
         pSysmanDeviceImp->init();
@@ -86,9 +87,9 @@ class SysmanDeviceFixture : public DeviceFixture, public ::testing::Test {
             GTEST_SKIP();
         }
 
-        if (GlobalOsSysmanDriver != nullptr) {
-            delete GlobalOsSysmanDriver;
-            GlobalOsSysmanDriver = nullptr;
+        if (globalOsSysmanDriver != nullptr) {
+            delete globalOsSysmanDriver;
+            globalOsSysmanDriver = nullptr;
         }
 
         DeviceFixture::tearDown();
@@ -114,7 +115,7 @@ class SysmanMultiDeviceFixture : public MultiDeviceFixture, public ::testing::Te
         device = driverHandle->devices[0];
         neoDevice = device->getNEODevice();
         neoDevice->getExecutionEnvironment()->rootDeviceEnvironments[device->getRootDeviceIndex()]->osInterface = std::make_unique<NEO::OSInterface>();
-        auto &osInterface = device->getOsInterface();
+        auto &osInterface = *device->getOsInterface();
         osInterface.setDriverModel(std::make_unique<SysmanMockDrm>(const_cast<NEO::RootDeviceEnvironment &>(neoDevice->getRootDeviceEnvironment())));
         setenv("ZES_ENABLE_SYSMAN", "1", 1);
         device->setSysmanHandle(new SysmanDeviceImp(device->toHandle()));
@@ -134,8 +135,8 @@ class SysmanMultiDeviceFixture : public MultiDeviceFixture, public ::testing::Te
         pLinuxSysmanImp->pSysfsAccess = pSysfsAccess;
         pLinuxSysmanImp->pProcfsAccess = pProcfsAccess;
 
-        if (GlobalOsSysmanDriver == nullptr) {
-            GlobalOsSysmanDriver = L0::OsSysmanDriver::create();
+        if (globalOsSysmanDriver == nullptr) {
+            globalOsSysmanDriver = L0::OsSysmanDriver::create();
         }
 
         pSysmanDeviceImp->init();
@@ -146,9 +147,9 @@ class SysmanMultiDeviceFixture : public MultiDeviceFixture, public ::testing::Te
         if (!sysmanUltsEnable) {
             GTEST_SKIP();
         }
-        if (GlobalOsSysmanDriver != nullptr) {
-            delete GlobalOsSysmanDriver;
-            GlobalOsSysmanDriver = nullptr;
+        if (globalOsSysmanDriver != nullptr) {
+            delete globalOsSysmanDriver;
+            globalOsSysmanDriver = nullptr;
         }
         unsetenv("ZES_ENABLE_SYSMAN");
         MultiDeviceFixture::tearDown();
