@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2023 Intel Corporation
+ * Copyright (C) 2021-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -22,7 +22,6 @@ namespace ult {
 constexpr int32_t memoryBusWidth = 128; // bus width in bytes
 constexpr int32_t numMemoryChannels = 8;
 constexpr uint32_t memoryHandleComponentCount = 1u;
-const std::string sampleGuid1 = "0xb15a0edc";
 
 class SysmanMemoryMockIoctlHelper : public NEO::MockIoctlHelper {
 
@@ -80,7 +79,7 @@ class SysmanDeviceMemoryFixture : public SysmanDeviceFixture {
         pFsAccess = std::make_unique<MockMemoryFsAccess>();
         pFsAccessOriginal = pLinuxSysmanImp->pFsAccess;
         pLinuxSysmanImp->pFsAccess = pFsAccess.get();
-        pDrm->setMemoryType(INTEL_HWCONFIG_MEMORY_TYPE_HBM2e);
+        pDrm->setMemoryType(NEO::DeviceBlobConstants::MemoryType::hbm2e);
         pDrm->ioctlHelper = static_cast<std::unique_ptr<NEO::IoctlHelper>>(std::make_unique<SysmanMemoryMockIoctlHelper>(*pDrm));
 
         pSysmanDeviceImp->pMemoryHandleContext->handleList.clear();
@@ -237,6 +236,7 @@ TEST_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingZetSysmanMemo
     auto handles = getMemoryHandles(memoryHandleComponentCount);
 
     for (auto handle : handles) {
+        ASSERT_NE(nullptr, handle);
         zes_mem_properties_t properties;
 
         ze_result_t result = zesMemoryGetProperties(handle, &properties);
@@ -260,6 +260,7 @@ TEST_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingZetSysmanMemo
     auto handles = getMemoryHandles(memoryHandleComponentCount);
 
     for (auto handle : handles) {
+        ASSERT_NE(nullptr, handle);
         zes_mem_properties_t properties;
 
         ze_result_t result = zesMemoryGetProperties(handle, &properties);
@@ -282,6 +283,7 @@ TEST_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingZetSysmanMemo
     auto handles = getMemoryHandles(memoryHandleComponentCount);
 
     for (auto handle : handles) {
+        ASSERT_NE(nullptr, handle);
         zes_mem_properties_t properties;
 
         ze_result_t result = zesMemoryGetProperties(handle, &properties);
@@ -298,12 +300,13 @@ TEST_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingZetSysmanMemo
 }
 
 TEST_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingZetSysmanMemoryGetPropertiesWithHBMLocalMemoryThenVerifySysmanMemoryGetPropertiesCallSucceeds) {
-    pDrm->setMemoryType(INTEL_HWCONFIG_MEMORY_TYPE_HBM2);
+    pDrm->setMemoryType(NEO::DeviceBlobConstants::MemoryType::hbm2);
     setLocalSupportedAndReinit(true);
 
     auto handles = getMemoryHandles(memoryHandleComponentCount);
 
     for (auto handle : handles) {
+        ASSERT_NE(nullptr, handle);
         zes_mem_properties_t properties;
 
         ze_result_t result = zesMemoryGetProperties(handle, &properties);
@@ -320,12 +323,13 @@ TEST_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingZetSysmanMemo
 }
 
 TEST_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingZetSysmanMemoryGetPropertiesWithLPDDR4LocalMemoryThenVerifySysmanMemoryGetPropertiesCallSucceeds) {
-    pDrm->setMemoryType(INTEL_HWCONFIG_MEMORY_TYPE_LPDDR4);
+    pDrm->setMemoryType(NEO::DeviceBlobConstants::MemoryType::lpddr4);
     setLocalSupportedAndReinit(true);
 
     auto handles = getMemoryHandles(memoryHandleComponentCount);
 
     for (auto handle : handles) {
+        ASSERT_NE(nullptr, handle);
         zes_mem_properties_t properties;
 
         ze_result_t result = zesMemoryGetProperties(handle, &properties);
@@ -342,12 +346,13 @@ TEST_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingZetSysmanMemo
 }
 
 TEST_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingZetSysmanMemoryGetPropertiesWithLPDDR5LocalMemoryThenVerifySysmanMemoryGetPropertiesCallSucceeds) {
-    pDrm->setMemoryType(INTEL_HWCONFIG_MEMORY_TYPE_LPDDR5);
+    pDrm->setMemoryType(NEO::DeviceBlobConstants::MemoryType::lpddr5);
     setLocalSupportedAndReinit(true);
 
     auto handles = getMemoryHandles(memoryHandleComponentCount);
 
     for (auto handle : handles) {
+        ASSERT_NE(nullptr, handle);
         zes_mem_properties_t properties;
 
         ze_result_t result = zesMemoryGetProperties(handle, &properties);
@@ -364,12 +369,13 @@ TEST_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingZetSysmanMemo
 }
 
 TEST_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingZetSysmanMemoryGetPropertiesWithDDRLocalMemoryThenVerifySysmanMemoryGetPropertiesCallSucceeds) {
-    pDrm->setMemoryType(INTEL_HWCONFIG_MEMORY_TYPE_GDDR6);
+    pDrm->setMemoryType(NEO::DeviceBlobConstants::MemoryType::gddr6);
     setLocalSupportedAndReinit(true);
 
     auto handles = getMemoryHandles(memoryHandleComponentCount);
 
     for (auto handle : handles) {
+        ASSERT_NE(nullptr, handle);
         zes_mem_properties_t properties;
 
         ze_result_t result = zesMemoryGetProperties(handle, &properties);
@@ -385,12 +391,13 @@ TEST_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingZetSysmanMemo
     }
 }
 
-TEST_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingZetSysmanMemoryGetStateThenVerifySysmanMemoryGetStateCallSucceeds) {
+HWTEST2_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingZesMemoryGetStateThenVerifySysmanMemoryGetStateCallSucceedsAndHealthIsOK, IsPVC) {
     setLocalSupportedAndReinit(true);
 
     auto handles = getMemoryHandles(memoryHandleComponentCount);
 
     for (auto handle : handles) {
+        ASSERT_NE(nullptr, handle);
         zes_mem_state_t state;
 
         ze_result_t result = zesMemoryGetState(handle, &state);
@@ -402,6 +409,24 @@ TEST_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingZetSysmanMemo
     }
 }
 
+HWTEST2_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingZetSysmanMemoryGetStateThenVerifySysmanMemoryGetStateCallSucceedsAndHealthIsUnknown, IsNotPVC) {
+    setLocalSupportedAndReinit(true);
+
+    auto handles = getMemoryHandles(memoryHandleComponentCount);
+
+    for (auto handle : handles) {
+        ASSERT_NE(nullptr, handle);
+        zes_mem_state_t state;
+
+        ze_result_t result = zesMemoryGetState(handle, &state);
+
+        EXPECT_EQ(result, ZE_RESULT_SUCCESS);
+        EXPECT_EQ(state.health, ZES_MEM_HEALTH_UNKNOWN);
+        EXPECT_EQ(state.size, NEO::probedSizeRegionOne);
+        EXPECT_EQ(state.free, NEO::unallocatedSizeRegionOne);
+    }
+}
+
 TEST_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingZetSysmanMemoryGetStateAndIoctlReturnedErrorThenApiReturnsError) {
     setLocalSupportedAndReinit(true);
 
@@ -409,6 +434,7 @@ TEST_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingZetSysmanMemo
     ioctlHelper->returnEmptyMemoryInfo = true;
     auto handles = getMemoryHandles(memoryHandleComponentCount);
     for (auto handle : handles) {
+        ASSERT_NE(nullptr, handle);
         zes_mem_state_t state;
 
         ze_result_t result = zesMemoryGetState(handle, &state);
@@ -427,6 +453,7 @@ TEST_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingZetSysmanMemo
     ioctlHelper->mockErrorNumber = ENODEV;
     auto handles = getMemoryHandles(memoryHandleComponentCount);
     for (auto handle : handles) {
+        ASSERT_NE(nullptr, handle);
         zes_mem_state_t state;
 
         ze_result_t result = zesMemoryGetState(handle, &state);
@@ -438,7 +465,7 @@ TEST_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingZetSysmanMemo
     }
 }
 
-TEST_F(SysmanDeviceMemoryFixture, GivenSysmanResourcesAreReleasedAndReInitializedWhenCallingZesSysmanMemoryGetStateThenVerifySysmanMemoryGetStateCallSucceeds) {
+HWTEST2_F(SysmanDeviceMemoryFixture, GivenSysmanResourcesAreReleasedAndReInitializedWhenCallingZesSysmanMemoryGetStateThenVerifySysmanMemoryGetStateCallSucceedsAndHealthIsOK, IsPVC) {
     pMemoryManager->localMemorySupported[0] = true;
 
     pLinuxSysmanImp->releaseSysmanDeviceResources();
@@ -461,6 +488,7 @@ TEST_F(SysmanDeviceMemoryFixture, GivenSysmanResourcesAreReleasedAndReInitialize
     auto handles = getMemoryHandles(memoryHandleComponentCount);
 
     for (auto handle : handles) {
+        ASSERT_NE(nullptr, handle);
         zes_mem_state_t state;
 
         ze_result_t result = zesMemoryGetState(handle, &state);
@@ -476,6 +504,45 @@ TEST_F(SysmanDeviceMemoryFixture, GivenSysmanResourcesAreReleasedAndReInitialize
     pLinuxSysmanImp->pFwUtilInterface = nullptr;
 }
 
+HWTEST2_F(SysmanDeviceMemoryFixture, GivenSysmanResourcesAreReleasedAndReInitializedWhenCallingZesSysmanMemoryGetStateThenVerifySysmanMemoryGetStateCallSucceedsAndHealthIsUnknown, IsNotPVC) {
+    pMemoryManager->localMemorySupported[0] = true;
+
+    pLinuxSysmanImp->releaseSysmanDeviceResources();
+    pLinuxSysmanImp->pDrm = pDrm;
+    pLinuxSysmanImp->reInitSysmanDeviceResources();
+
+    VariableBackup<std::map<uint32_t, PlatformMonitoringTech *>> pmtBackup(&pLinuxSysmanImp->mapOfSubDeviceIdToPmtObject);
+    pLinuxSysmanImp->mapOfSubDeviceIdToPmtObject.clear();
+    for (auto &deviceHandle : deviceHandles) {
+        ze_device_properties_t deviceProperties = {ZE_STRUCTURE_TYPE_DEVICE_PROPERTIES};
+        Device::fromHandle(deviceHandle)->getProperties(&deviceProperties);
+        auto pPmt = new MockMemoryPmt(pFsAccess.get(), deviceProperties.flags & ZE_DEVICE_PROPERTY_FLAG_SUBDEVICE,
+                                      deviceProperties.subdeviceId);
+        pLinuxSysmanImp->mapOfSubDeviceIdToPmtObject.emplace(deviceProperties.subdeviceId, pPmt);
+    }
+
+    VariableBackup<FirmwareUtil *> backup(&pLinuxSysmanImp->pFwUtilInterface);
+    pLinuxSysmanImp->pFwUtilInterface = new MockFwUtilInterface();
+
+    auto handles = getMemoryHandles(memoryHandleComponentCount);
+
+    for (auto handle : handles) {
+        ASSERT_NE(nullptr, handle);
+        zes_mem_state_t state;
+
+        ze_result_t result = zesMemoryGetState(handle, &state);
+
+        EXPECT_EQ(result, ZE_RESULT_SUCCESS);
+        EXPECT_EQ(state.health, ZES_MEM_HEALTH_UNKNOWN);
+        EXPECT_EQ(state.size, NEO::probedSizeRegionOne);
+        EXPECT_EQ(state.free, NEO::unallocatedSizeRegionOne);
+    }
+
+    pLinuxSysmanImp->releasePmtObject();
+    delete pLinuxSysmanImp->pFwUtilInterface;
+    pLinuxSysmanImp->pFwUtilInterface = nullptr;
+}
+
 TEST_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingzesSysmanMemoryGetBandwidthWhenPmtObjectIsNullThenFailureRetuned) {
     for (auto &subDeviceIdToPmtEntry : pLinuxSysmanImp->mapOfSubDeviceIdToPmtObject) {
         if (subDeviceIdToPmtEntry.second != nullptr) {
@@ -486,6 +553,7 @@ TEST_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingzesSysmanMemo
     setLocalSupportedAndReinit(true);
     auto handles = getMemoryHandles(memoryHandleComponentCount);
     for (auto &handle : handles) {
+        ASSERT_NE(nullptr, handle);
         zes_mem_bandwidth_t bandwidth;
         EXPECT_EQ(zesMemoryGetBandwidth(handle, &bandwidth), ZE_RESULT_ERROR_UNSUPPORTED_FEATURE);
     }
@@ -496,6 +564,7 @@ HWTEST2_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingzesSysmanM
     auto handles = getMemoryHandles(memoryHandleComponentCount);
 
     for (auto &handle : handles) {
+        ASSERT_NE(nullptr, handle);
         zes_mem_bandwidth_t bandwidth{};
         uint64_t expectedReadCounters = 0, expectedWriteCounters = 0;
         uint64_t expectedBandwidth = 0;
@@ -512,12 +581,12 @@ HWTEST2_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingzesSysmanM
         pSysfsAccess->mockReadReturnStatus.push_back(ZE_RESULT_SUCCESS);
 
         EXPECT_EQ(zesMemoryGetBandwidth(handle, &bandwidth), ZE_RESULT_SUCCESS);
-        expectedReadCounters |= VF0HbmHRead;
-        expectedReadCounters = (expectedReadCounters << 32) | VF0HbmLRead;
+        expectedReadCounters |= vF0HbmHRead;
+        expectedReadCounters = (expectedReadCounters << 32) | vF0HbmLRead;
         expectedReadCounters = expectedReadCounters * transactionSize;
         EXPECT_EQ(bandwidth.readCounter, expectedReadCounters);
-        expectedWriteCounters |= VF0HbmHWrite;
-        expectedWriteCounters = (expectedWriteCounters << 32) | VF0HbmLWrite;
+        expectedWriteCounters |= vF0HbmHWrite;
+        expectedWriteCounters = (expectedWriteCounters << 32) | vF0HbmLWrite;
         expectedWriteCounters = expectedWriteCounters * transactionSize;
         EXPECT_EQ(bandwidth.writeCounter, expectedWriteCounters);
         expectedBandwidth = 128 * hbmRP0Frequency * 1000 * 1000 * 4;
@@ -530,6 +599,7 @@ HWTEST2_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingzesSysmanM
     auto handles = getMemoryHandles(memoryHandleComponentCount);
 
     for (auto &handle : handles) {
+        ASSERT_NE(nullptr, handle);
         zes_mem_bandwidth_t bandwidth{};
         uint64_t expectedReadCounters = 0, expectedWriteCounters = 0;
         uint64_t expectedBandwidth = 0;
@@ -546,12 +616,12 @@ HWTEST2_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingzesSysmanM
         pSysfsAccess->mockReadReturnStatus.push_back(ZE_RESULT_SUCCESS);
 
         EXPECT_EQ(zesMemoryGetBandwidth(handle, &bandwidth), ZE_RESULT_SUCCESS);
-        expectedReadCounters |= VF0HbmHRead;
-        expectedReadCounters = (expectedReadCounters << 32) | VF0HbmLRead;
+        expectedReadCounters |= vF0HbmHRead;
+        expectedReadCounters = (expectedReadCounters << 32) | vF0HbmLRead;
         expectedReadCounters = expectedReadCounters * transactionSize;
         EXPECT_EQ(bandwidth.readCounter, expectedReadCounters);
-        expectedWriteCounters |= VF0HbmHWrite;
-        expectedWriteCounters = (expectedWriteCounters << 32) | VF0HbmLWrite;
+        expectedWriteCounters |= vF0HbmHWrite;
+        expectedWriteCounters = (expectedWriteCounters << 32) | vF0HbmLWrite;
         expectedWriteCounters = expectedWriteCounters * transactionSize;
         EXPECT_EQ(bandwidth.writeCounter, expectedWriteCounters);
         expectedBandwidth = 128 * hbmRP0Frequency * 1000 * 1000 * 4;
@@ -564,6 +634,7 @@ HWTEST2_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingzesSysmanM
     auto handles = getMemoryHandles(memoryHandleComponentCount);
 
     for (auto &handle : handles) {
+        ASSERT_NE(nullptr, handle);
         zes_mem_properties_t properties = {};
         zesMemoryGetProperties(handle, &properties);
 
@@ -586,6 +657,7 @@ HWTEST2_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingzesSysmanM
     auto handles = getMemoryHandles(memoryHandleComponentCount);
 
     for (auto &handle : handles) {
+        ASSERT_NE(nullptr, handle);
         zes_mem_properties_t properties = {};
         zesMemoryGetProperties(handle, &properties);
 
@@ -604,6 +676,7 @@ HWTEST2_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingzesSysmanM
     auto handles = getMemoryHandles(memoryHandleComponentCount);
 
     for (auto &handle : handles) {
+        ASSERT_NE(nullptr, handle);
         zes_mem_properties_t properties = {};
         zesMemoryGetProperties(handle, &properties);
 
@@ -624,6 +697,7 @@ HWTEST2_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingzesSysmanM
     auto handles = getMemoryHandles(memoryHandleComponentCount);
 
     for (auto &handle : handles) {
+        ASSERT_NE(nullptr, handle);
         zes_mem_properties_t properties = {};
         zesMemoryGetProperties(handle, &properties);
 
@@ -648,6 +722,7 @@ HWTEST2_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingzesSysmanM
     auto handles = getMemoryHandles(memoryHandleComponentCount);
 
     for (auto &handle : handles) {
+        ASSERT_NE(nullptr, handle);
         zes_mem_properties_t properties = {};
         zesMemoryGetProperties(handle, &properties);
 
@@ -674,6 +749,7 @@ HWTEST2_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingzesSysmanM
     auto handles = getMemoryHandles(memoryHandleComponentCount);
 
     for (auto &handle : handles) {
+        ASSERT_NE(nullptr, handle);
         zes_mem_properties_t properties = {};
         zesMemoryGetProperties(handle, &properties);
 
@@ -702,6 +778,7 @@ HWTEST2_F(SysmanDeviceMemoryFixture, GivenValidUsRevIdForRevisionBWhenCallingzes
     auto handles = getMemoryHandles(memoryHandleComponentCount);
 
     for (auto &handle : handles) {
+        ASSERT_NE(nullptr, handle);
         zes_mem_bandwidth_t bandwidth{};
         zes_mem_properties_t properties = {ZES_STRUCTURE_TYPE_MEM_PROPERTIES};
         zesMemoryGetProperties(handle, &properties);
@@ -729,6 +806,7 @@ TEST_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingzesSysmanMemo
     auto handles = getMemoryHandles(memoryHandleComponentCount);
 
     for (const auto &handle : handles) {
+        ASSERT_NE(nullptr, handle);
         zes_mem_properties_t properties = {};
         zesMemoryGetProperties(handle, &properties);
 
@@ -742,7 +820,7 @@ TEST_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingzesSysmanMemo
         EXPECT_EQ(expectedReadCounters, bandwidth.readCounter);
         expectedWriteCounters = numberMcChannels * mockIdiWriteVal * transactionSize;
         EXPECT_EQ(expectedWriteCounters, bandwidth.writeCounter);
-        expectedBandwidth = mockMaxBwDg2 * MbpsToBytesPerSecond;
+        expectedBandwidth = mockMaxBwDg2 * mbpsToBytesPerSecond;
         EXPECT_EQ(expectedBandwidth, bandwidth.maxBandwidth);
         EXPECT_GT(bandwidth.timestamp, 0u);
     }
@@ -756,6 +834,7 @@ TEST_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingzesSysmanMemo
     auto handles = getMemoryHandles(memoryHandleComponentCount);
 
     for (const auto &handle : handles) {
+        ASSERT_NE(nullptr, handle);
         zes_mem_bandwidth_t bandwidth;
         EXPECT_EQ(zesMemoryGetBandwidth(handle, &bandwidth), ZE_RESULT_ERROR_UNSUPPORTED_FEATURE);
     }
@@ -769,6 +848,7 @@ TEST_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingzesSysmanMemo
     auto handles = getMemoryHandles(memoryHandleComponentCount);
 
     for (auto handle : handles) {
+        ASSERT_NE(nullptr, handle);
         zes_mem_properties_t properties = {};
         zesMemoryGetProperties(handle, &properties);
 
@@ -788,6 +868,7 @@ HWTEST2_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingzesSysmanM
     auto handles = getMemoryHandles(memoryHandleComponentCount);
 
     for (const auto &handle : handles) {
+        ASSERT_NE(nullptr, handle);
         zes_mem_properties_t properties = {};
         zesMemoryGetProperties(handle, &properties);
 
@@ -807,6 +888,7 @@ TEST_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingzesSysmanMemo
     auto handles = getMemoryHandles(memoryHandleComponentCount);
 
     for (auto handle : handles) {
+        ASSERT_NE(nullptr, handle);
         zes_mem_properties_t properties = {};
         zesMemoryGetProperties(handle, &properties);
 
@@ -826,6 +908,7 @@ TEST_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingzesSysmanMemo
     auto handles = getMemoryHandles(memoryHandleComponentCount);
 
     for (auto handle : handles) {
+        ASSERT_NE(nullptr, handle);
         zes_mem_properties_t properties = {};
         zesMemoryGetProperties(handle, &properties);
 
@@ -889,6 +972,7 @@ TEST_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenBothVfid0AndVfid1Are
     auto handles = getMemoryHandles(memoryHandleComponentCount);
 
     for (auto handle : handles) {
+        ASSERT_NE(nullptr, handle);
         zes_mem_properties_t properties = {};
         zesMemoryGetProperties(handle, &properties);
 
@@ -911,6 +995,7 @@ TEST_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenBothVfid0AndVfid1Are
     auto handles = getMemoryHandles(memoryHandleComponentCount);
 
     for (auto handle : handles) {
+        ASSERT_NE(nullptr, handle);
         zes_mem_properties_t properties = {};
         zesMemoryGetProperties(handle, &properties);
 
@@ -946,6 +1031,7 @@ TEST_F(SysmanDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingZesSysmanMemo
     pLinuxSysmanImp->pFwUtilInterface = nullptr;
 
     for (auto handle : handles) {
+        ASSERT_NE(nullptr, handle);
         zes_mem_state_t state;
         ze_result_t result = zesMemoryGetState(handle, &state);
 
@@ -1104,10 +1190,14 @@ TEST_F(SysmanMultiDeviceMemoryFixture, GivenValidDevicePointerWhenGettingMemoryP
     }
 }
 
-TEST_F(SysmanMultiDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingZetSysmanMemoryGetStateThenVerifySysmanMemoryGetStateCallSucceeds) {
+HWTEST2_F(SysmanMultiDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingZetSysmanMemoryGetStateThenVerifySysmanMemoryGetStateCallSucceedsAndHealthIsOK, IsPVC) {
     setLocalSupportedAndReinit(true);
 
     auto handles = getMemoryHandles(subDeviceCount);
+
+    for (auto handle : handles) {
+        ASSERT_NE(nullptr, handle);
+    }
     zes_mem_state_t state1;
     ze_result_t result = zesMemoryGetState(handles[0], &state1);
     EXPECT_EQ(result, ZE_RESULT_SUCCESS);
@@ -1123,5 +1213,28 @@ TEST_F(SysmanMultiDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingZetSysma
     EXPECT_EQ(state2.free, NEO::unallocatedSizeRegionFour);
 }
 
+HWTEST2_F(SysmanMultiDeviceMemoryFixture, GivenValidMemoryHandleWhenCallingZetSysmanMemoryGetStateThenVerifySysmanMemoryGetStateCallSucceedsAndHealthIsUnknown, IsNotPVC) {
+    setLocalSupportedAndReinit(true);
+
+    auto handles = getMemoryHandles(subDeviceCount);
+
+    for (auto handle : handles) {
+        ASSERT_NE(nullptr, handle);
+    }
+    zes_mem_state_t state1;
+    ze_result_t result = zesMemoryGetState(handles[0], &state1);
+    EXPECT_EQ(result, ZE_RESULT_SUCCESS);
+    EXPECT_EQ(state1.health, ZES_MEM_HEALTH_UNKNOWN);
+    EXPECT_EQ(state1.size, NEO::probedSizeRegionOne);
+    EXPECT_EQ(state1.free, NEO::unallocatedSizeRegionOne);
+
+    zes_mem_state_t state2;
+    result = zesMemoryGetState(handles[1], &state2);
+    EXPECT_EQ(result, ZE_RESULT_SUCCESS);
+    EXPECT_EQ(state2.health, ZES_MEM_HEALTH_UNKNOWN);
+    EXPECT_EQ(state2.size, NEO::probedSizeRegionFour);
+    EXPECT_EQ(state2.free, NEO::unallocatedSizeRegionFour);
+}
+
 } // namespace ult
 } // namespace L0
