@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2023 Intel Corporation
+ * Copyright (C) 2018-2024 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -30,21 +30,21 @@ void populateKernelDescriptor(KernelDescriptor &dst, const SPatchExecutionEnviro
 
 struct MockKernelObjForAuxTranslation : public KernelObjForAuxTranslation {
     MockKernelObjForAuxTranslation(Type type) : KernelObjForAuxTranslation(type, nullptr) {
-        if (type == KernelObjForAuxTranslation::Type::MEM_OBJ) {
+        if (type == KernelObjForAuxTranslation::Type::memObj) {
             mockBuffer.reset(new MockBuffer);
             this->object = mockBuffer.get();
         } else {
-            DEBUG_BREAK_IF(type != KernelObjForAuxTranslation::Type::GFX_ALLOC);
+            DEBUG_BREAK_IF(type != KernelObjForAuxTranslation::Type::gfxAlloc);
             mockGraphicsAllocation.reset(new MockGraphicsAllocation(nullptr, 0x100));
             this->object = mockGraphicsAllocation.get();
         }
     };
 
     MockKernelObjForAuxTranslation(Type type, size_t size) : MockKernelObjForAuxTranslation(type) {
-        if (type == KernelObjForAuxTranslation::Type::MEM_OBJ) {
+        if (type == KernelObjForAuxTranslation::Type::memObj) {
             mockBuffer->getGraphicsAllocation(0)->setSize(size);
         } else {
-            DEBUG_BREAK_IF(type != KernelObjForAuxTranslation::Type::GFX_ALLOC);
+            DEBUG_BREAK_IF(type != KernelObjForAuxTranslation::Type::gfxAlloc);
             mockGraphicsAllocation->setSize(size);
         }
     }
@@ -62,7 +62,7 @@ class MockMultiDeviceKernel : public MultiDeviceKernel {
         return kernelVector;
     }
     using MultiDeviceKernel::MultiDeviceKernel;
-    template <typename kernel_t = Kernel>
+    template <typename KernelType = Kernel>
     static MockMultiDeviceKernel *create(Program *programArg, const KernelInfoContainer &kernelInfoArg) {
         KernelVectorType kernelVector;
         kernelVector.resize(programArg->getMaxRootDeviceIndex() + 1);
@@ -71,7 +71,7 @@ class MockMultiDeviceKernel : public MultiDeviceKernel {
             if (kernelVector[rootDeviceIndex]) {
                 continue;
             }
-            kernelVector[rootDeviceIndex] = new kernel_t(programArg, *kernelInfoArg[rootDeviceIndex], *pDevice);
+            kernelVector[rootDeviceIndex] = new KernelType(programArg, *kernelInfoArg[rootDeviceIndex], *pDevice);
         }
         return new MockMultiDeviceKernel(std::move(kernelVector), kernelInfoArg);
     }
@@ -98,6 +98,8 @@ class MockKernel : public Kernel {
     using Kernel::anyKernelArgumentUsingSystemMemory;
     using Kernel::auxTranslationRequired;
     using Kernel::containsStatelessWrites;
+    using Kernel::crossThreadData;
+    using Kernel::crossThreadDataSize;
     using Kernel::dataParameterSimdSize;
     using Kernel::executionType;
     using Kernel::getDevice;
@@ -151,7 +153,7 @@ class MockKernel : public Kernel {
 
     template <typename KernelType = MockKernel>
     static KernelType *create(Device &device, Program *program) {
-        return create<KernelType>(device, program, GrfConfig::DefaultGrfNumber);
+        return create<KernelType>(device, program, GrfConfig::defaultGrfNumber);
     }
 
     template <typename KernelType = MockKernel>
@@ -181,8 +183,6 @@ class MockKernel : public Kernel {
 
     bool isPatched() const override;
 
-    bool canTransformImages() const override;
-
     ////////////////////////////////////////////////////////////////////////////////
     void setCrossThreadData(const void *crossThreadDataPattern, uint32_t newCrossThreadDataSize) {
         if ((crossThreadData != nullptr) && (crossThreadData != mockCrossThreadData.data())) {
@@ -191,8 +191,7 @@ class MockKernel : public Kernel {
             crossThreadDataSize = 0;
         }
         if (crossThreadDataPattern && (newCrossThreadDataSize > 0)) {
-            mockCrossThreadData.clear();
-            mockCrossThreadData.insert(mockCrossThreadData.begin(), (char *)crossThreadDataPattern, ((char *)crossThreadDataPattern) + newCrossThreadDataSize);
+            mockCrossThreadData.assign((char *)crossThreadDataPattern, ((char *)crossThreadDataPattern) + newCrossThreadDataSize);
         } else {
             mockCrossThreadData.resize(newCrossThreadDataSize, 0);
         }
@@ -246,8 +245,6 @@ class MockKernel : public Kernel {
 
     void setSystolicPipelineSelectMode(bool value) { systolicPipelineSelectMode = value; }
 
-    bool requiresCacheFlushCommand(const CommandQueue &commandQueue) const override;
-
     cl_int setArgSvmAlloc(uint32_t argIndex, void *svmPtr, GraphicsAllocation *svmAlloc, uint32_t allocId) override;
 
     uint32_t makeResidentCalls = 0;
@@ -276,7 +273,7 @@ class MockKernelWithInternals {
         kernelInfo.heapInfo.dynamicStateHeapSize = sizeof(dshLocal);
 
         populateKernelDescriptor(kernelInfo.kernelDescriptor, execEnv);
-        kernelInfo.kernelDescriptor.kernelAttributes.numGrfRequired = GrfConfig::DefaultGrfNumber;
+        kernelInfo.kernelDescriptor.kernelAttributes.numGrfRequired = GrfConfig::defaultGrfNumber;
         kernelInfo.kernelDescriptor.kernelAttributes.simdSize = 32;
         kernelInfo.setCrossThreadDataSize(sizeof(crossThreadData));
         kernelInfo.setLocalIds({1, 1, 1});
@@ -353,18 +350,18 @@ class MockKernelWithInternals {
     operator MockKernel *() {
         return mockKernel;
     }
+    alignas(64) char sshLocal[128];
+    alignas(64) char dshLocal[128];
+    char crossThreadData[256];
+    uint32_t kernelIsa[32];
+    MockKernelInfo kernelInfo;
 
     MockMultiDeviceKernel *mockMultiDeviceKernel = nullptr;
     MockKernel *mockKernel;
     MockProgram *mockProgram;
     Context *mockContext;
     KernelInfoContainer kernelInfos;
-    MockKernelInfo kernelInfo;
     SKernelBinaryHeaderCommon kernelHeader = {};
-    uint32_t kernelIsa[32];
-    char crossThreadData[256];
-    alignas(64) char sshLocal[128];
-    alignas(64) char dshLocal[128];
     std::vector<Kernel::SimpleKernelArgInfo> defaultKernelArguments;
 };
 class MockDebugKernel : public MockKernel {
