@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2023 Intel Corporation
+ * Copyright (C) 2018-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -23,13 +23,6 @@ void cleanTestHelpers() {
     delete platformsImpl;
 }
 
-void initGTest(int &argc, char **argv) {
-    ::testing::InitGoogleTest(&argc, argv);
-}
-bool isPlatformSupported(const HardwareInfo &hwInfoForTests) {
-    return true;
-}
-
 void setupTestFiles(std::string testBinaryFiles, int32_t revId) {
     testBinaryFiles.append("/");
     testBinaryFiles.append(binaryNameSuffix);
@@ -45,7 +38,7 @@ void setupTestFiles(std::string testBinaryFiles, int32_t revId) {
 }
 
 std::string getBaseExecutionDir() {
-    if (testMode != TestMode::AubTests) {
+    if (testMode != TestMode::aubTests) {
         return "opencl/";
     }
     return "";
