@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2024 Intel Corporation
+ * Copyright (C) 2021-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -50,17 +50,17 @@ const uint32_t microsecondAdjustment = 1000;
 
 AILConfigurationCreateFunctionType ailConfigurationFactory[IGFX_MAX_PRODUCT];
 
-void AILConfiguration::apply(RuntimeCapabilityTable &runtimeCapabilityTable) {
+void AILConfiguration::apply(HardwareInfo &hwInfo) {
     auto search = applicationMap.find(processName);
 
     if (search != applicationMap.end()) {
         for (size_t i = 0; i < search->second.size(); ++i) {
             switch (search->second[i]) {
             case AILEnumeration::enableFp64:
-                runtimeCapabilityTable.ftrSupportsFP64 = true;
+                hwInfo.capabilityTable.ftrSupportsFP64 = true;
                 break;
             case AILEnumeration::enableLegacyPlatformName:
-                runtimeCapabilityTable.preferredPlatformName = legacyPlatformName;
+                hwInfo.capabilityTable.preferredPlatformName = legacyPlatformName;
                 break;
             default:
                 break;
@@ -68,7 +68,7 @@ void AILConfiguration::apply(RuntimeCapabilityTable &runtimeCapabilityTable) {
         }
     }
 
-    applyExt(runtimeCapabilityTable);
+    applyExt(hwInfo);
 }
 
 } // namespace NEO
