@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2019-2021 Intel Corporation
+ * Copyright (C) 2019-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -17,17 +17,12 @@ class SubDevice : public Device {
     void incRefInternal() override;
     unique_ptr_if_unused<Device> decRefInternal() override;
 
-    uint32_t getRootDeviceIndex() const override;
-
     Device *getRootDevice() const override;
 
     uint32_t getSubDeviceIndex() const;
     bool isSubDevice() const override { return true; }
 
   protected:
-    uint64_t getGlobalMemorySize(uint32_t deviceBitfield) const override;
-    bool genericSubDevicesAllowed() override { return false; };
-
     RootDevice &rootDevice;
     const uint32_t subDeviceIndex;
 };
