@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2024 Intel Corporation
+ * Copyright (C) 2018-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -20,6 +20,7 @@
 #include "shared/source/helpers/string_helpers.h"
 #include "shared/source/memory_manager/memory_manager.h"
 #include "shared/source/memory_manager/os_agnostic_memory_manager.h"
+#include "shared/source/memory_manager/unified_memory_reuse_cleaner.h"
 #include "shared/source/os_interface/debug_env_reader.h"
 #include "shared/source/os_interface/driver_info.h"
 #include "shared/source/os_interface/os_environment.h"
@@ -50,6 +51,9 @@ ExecutionEnvironment::~ExecutionEnvironment() {
     if (directSubmissionController) {
         directSubmissionController->stopThread();
     }
+    if (unifiedMemoryReuseCleaner) {
+        unifiedMemoryReuseCleaner->stopThread();
+    }
     if (memoryManager) {
         memoryManager->commonCleanup();
         for (const auto &rootDeviceEnvironment : this->rootDeviceEnvironments) {
@@ -111,7 +115,7 @@ void ExecutionEnvironment::calculateMaxOsContextCount() {
 
         uint32_t numRootContexts = hasRootCsr ? 1 : 0;
         uint32_t numSecondaryContexts = 0;
-        if (gfxCoreHelper.getContextGroupContextsCount() > 0) {
+        if (gfxCoreHelper.areSecondaryContextsSupported()) {
             numSecondaryContexts += numRegularEngines * gfxCoreHelper.getContextGroupContextsCount();
             numSecondaryContexts += numHpEngines * gfxCoreHelper.getContextGroupContextsCount();
             osContextCount -= (numRegularEngines + numHpEngines);
@@ -143,6 +147,20 @@ DirectSubmissionController *ExecutionEnvironment::initializeDirectSubmissionCont
     return directSubmissionController.get();
 }
 
+void ExecutionEnvironment::initializeUnifiedMemoryReuseCleaner() {
+    std::lock_guard<std::mutex> lock(initializeUnifiedMemoryReuseCleanerMutex);
+    auto initializeUnifiedMemoryReuseCleaner = UnifiedMemoryReuseCleaner::isSupported();
+
+    if (debugManager.flags.ExperimentalUSMAllocationReuseCleaner.get() != -1) {
+        initializeUnifiedMemoryReuseCleaner = debugManager.flags.ExperimentalUSMAllocationReuseCleaner.get() == 1;
+    }
+
+    if (initializeUnifiedMemoryReuseCleaner && nullptr == this->unifiedMemoryReuseCleaner) {
+        this->unifiedMemoryReuseCleaner = std::make_unique<UnifiedMemoryReuseCleaner>();
+        this->unifiedMemoryReuseCleaner->startThread();
+    }
+}
+
 void ExecutionEnvironment::prepareRootDeviceEnvironments(uint32_t numRootDevices) {
     if (rootDeviceEnvironments.size() < numRootDevices) {
         rootDeviceEnvironments.resize(numRootDevices);
@@ -212,12 +230,6 @@ bool ExecutionEnvironment::getSubDeviceHierarchy(uint32_t index, std::tuple<uint
 }
 
 void ExecutionEnvironment::parseAffinityMask() {
-
-    // If the device hierarchy is Combined, then skip the affinity mask parsing until level zero device get.
-    if (isCombinedDeviceHierarchy()) {
-        return;
-    }
-
     const auto &affinityMaskString = debugManager.flags.ZE_AFFINITY_MASK.get();
 
     if (affinityMaskString.compare("default") == 0 ||
@@ -225,19 +237,22 @@ void ExecutionEnvironment::parseAffinityMask() {
         return;
     }
 
-    // If the user has requested FLAT device hierarchy models, then report all the sub devices as devices.
-    bool exposeSubDevicesAsApiDevices = isExposingSubDevicesAsDevices();
-    uint32_t numRootDevices = static_cast<uint32_t>(rootDeviceEnvironments.size());
+    // If the user has requested FLAT or COMBINED device hierarchy models, then report all the sub devices as devices.
+    bool exposeSubDevices = this->deviceHierarchyMode != DeviceHierarchyMode::composite;
 
-    RootDeviceIndicesMap mapOfIndices;
     // Reserve at least for a size equal to rootDeviceEnvironments.size() times four,
     // which is enough for typical configurations
+    uint32_t numRootDevices = static_cast<uint32_t>(rootDeviceEnvironments.size());
+    uint32_t numDevices = numRootDevices;
     size_t reservedSizeForIndices = numRootDevices * 4;
+    RootDeviceIndicesMap mapOfIndices;
     mapOfIndices.reserve(reservedSizeForIndices);
     uint32_t hwSubDevicesCount = 0u;
-    if (exposeSubDevicesAsApiDevices) {
-        for (uint32_t currentRootDevice = 0u; currentRootDevice < static_cast<uint32_t>(rootDeviceEnvironments.size()); currentRootDevice++) {
+
+    if (exposeSubDevices) {
+        for (uint32_t currentRootDevice = 0u; currentRootDevice < numRootDevices; currentRootDevice++) {
             auto hwInfo = rootDeviceEnvironments[currentRootDevice]->getHardwareInfo();
+
             hwSubDevicesCount = GfxCoreHelper::getSubDevicesCount(hwInfo);
             uint32_t currentSubDevice = 0;
             mapOfIndices.push_back(std::make_tuple(currentRootDevice, currentSubDevice));
@@ -246,7 +261,7 @@ void ExecutionEnvironment::parseAffinityMask() {
             }
         }
 
-        numRootDevices = static_cast<uint32_t>(mapOfIndices.size());
+        numDevices = static_cast<uint32_t>(mapOfIndices.size());
     }
 
     std::vector<AffinityMaskHelper> affinityMaskHelper(numRootDevices);
@@ -257,32 +272,27 @@ void ExecutionEnvironment::parseAffinityMask() {
     uint32_t deviceIndex = 0;
     for (const auto &entry : affinityMaskEntries) {
         auto subEntries = StringHelpers::split(entry, ".");
-        uint32_t rootDeviceIndex = StringHelpers::toUint32t(subEntries[0]);
+        uint32_t entryIndex = StringHelpers::toUint32t(subEntries[0]);
 
-        // tiles as devices
-        if (exposeSubDevicesAsApiDevices) {
-            if (rootDeviceIndex >= numRootDevices) {
-                continue;
-            }
-
-            // FlatHierarchy
+        if (entryIndex >= numDevices) {
+            continue;
+        } else if (exposeSubDevices) {
+            // tiles as devices
             // so ignore X.Y
             if (subEntries.size() > 1) {
                 continue;
             }
 
-            std::tuple<uint32_t, uint32_t> indexKey = mapOfIndices[rootDeviceIndex];
+            std::tuple<uint32_t, uint32_t> indexKey = mapOfIndices[entryIndex];
             auto hwDeviceIndex = std::get<0>(indexKey);
             auto tileIndex = std::get<1>(indexKey);
+
             affinityMaskHelper[hwDeviceIndex].enableGenericSubDevice(tileIndex);
             // Store the Physical Hierarchy for this SubDevice mapped to the Device Index passed to the user.
             mapOfSubDeviceIndices[deviceIndex++] = std::make_tuple(hwDeviceIndex, tileIndex, hwSubDevicesCount);
-            continue;
-        }
-
-        // cards as devices
-        if (rootDeviceIndex < numRootDevices) {
-            auto hwInfo = rootDeviceEnvironments[rootDeviceIndex]->getHardwareInfo();
+        } else {
+            // cards as devices
+            auto hwInfo = rootDeviceEnvironments[entryIndex]->getHardwareInfo();
             auto subDevicesCount = GfxCoreHelper::getSubDevicesCount(hwInfo);
 
             if (subEntries.size() > 1) {
@@ -291,14 +301,14 @@ void ExecutionEnvironment::parseAffinityMask() {
                 if (subDeviceIndex < subDevicesCount) {
                     if (subEntries.size() == 2) {
                         // Store the Physical Hierarchy for this SubDevice mapped to the Device Index passed to the user.
-                        mapOfSubDeviceIndices[rootDeviceIndex] = std::make_tuple(rootDeviceIndex, subDeviceIndex, subDevicesCount);
-                        affinityMaskHelper[rootDeviceIndex].enableGenericSubDevice(subDeviceIndex); // Mask: X.Y
+                        mapOfSubDeviceIndices[entryIndex] = std::make_tuple(entryIndex, subDeviceIndex, subDevicesCount);
+                        affinityMaskHelper[entryIndex].enableGenericSubDevice(subDeviceIndex); // Mask: X.Y
                     } else {
                         UNRECOVERABLE_IF(subEntries.size() != 3);
                     }
                 }
             } else {
-                affinityMaskHelper[rootDeviceIndex].enableAllGenericSubDevices(subDevicesCount); // Mask: X
+                affinityMaskHelper[entryIndex].enableAllGenericSubDevices(subDevicesCount); // Mask: X
             }
         }
     }
@@ -320,17 +330,17 @@ void ExecutionEnvironment::sortNeoDevices() {
     std::sort(rootDeviceEnvironments.begin(), rootDeviceEnvironments.end(), comparePciIdBusNumber);
 }
 
-void ExecutionEnvironment::setDeviceHierarchy(const GfxCoreHelper &gfxCoreHelper) {
+void ExecutionEnvironment::setDeviceHierarchyMode(const GfxCoreHelper &gfxCoreHelper) {
     NEO::EnvironmentVariableReader envReader;
-    std::string hierarchyModel = envReader.getSetting("ZE_FLAT_DEVICE_HIERARCHY", std::string(gfxCoreHelper.getDefaultDeviceHierarchy()));
-    if (strcmp(hierarchyModel.c_str(), "COMPOSITE") == 0) {
-        setExposeSubDevicesAsDevices(false);
-    }
-    if (strcmp(hierarchyModel.c_str(), "FLAT") == 0) {
-        setExposeSubDevicesAsDevices(true);
-    }
-    if (strcmp(hierarchyModel.c_str(), "COMBINED") == 0) {
-        setCombinedDeviceHierarchy(true);
+    std::string deviceHierarchyMode = envReader.getSetting("ZE_FLAT_DEVICE_HIERARCHY", std::string(""));
+    if (strcmp(deviceHierarchyMode.c_str(), "COMPOSITE") == 0) {
+        this->deviceHierarchyMode = DeviceHierarchyMode::composite;
+    } else if (strcmp(deviceHierarchyMode.c_str(), "FLAT") == 0) {
+        this->deviceHierarchyMode = DeviceHierarchyMode::flat;
+    } else if (strcmp(deviceHierarchyMode.c_str(), "COMBINED") == 0) {
+        this->deviceHierarchyMode = DeviceHierarchyMode::combined;
+    } else {
+        this->deviceHierarchyMode = gfxCoreHelper.getDefaultDeviceHierarchy();
     }
 }
 
