@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2024 Intel Corporation
+ * Copyright (C) 2018-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -7,6 +7,7 @@
 
 #pragma once
 #include "shared/source/debugger/debugger.h"
+#include "shared/source/helpers/device_hierarchy_mode.h"
 #include "shared/source/utilities/reference_tracked_object.h"
 
 #include <mutex>
@@ -18,6 +19,7 @@
 
 namespace NEO {
 class DirectSubmissionController;
+class UnifiedMemoryReuseCleaner;
 class GfxCoreHelper;
 class MemoryManager;
 struct OsEnvironment;
@@ -38,7 +40,11 @@ class ExecutionEnvironment : public ReferenceTrackedObject<ExecutionEnvironment>
     void adjustCcsCount();
     void adjustCcsCount(const uint32_t rootDeviceIndex) const;
     void sortNeoDevices();
-    void setDeviceHierarchy(const GfxCoreHelper &gfxCoreHelper);
+    void setDeviceHierarchyMode(const GfxCoreHelper &gfxCoreHelper);
+    void setDeviceHierarchyMode(const DeviceHierarchyMode deviceHierarchyMode) {
+        this->deviceHierarchyMode = deviceHierarchyMode;
+    }
+    DeviceHierarchyMode getDeviceHierarchyMode() const { return deviceHierarchyMode; }
     void adjustRootDeviceEnvironments();
     void prepareForCleanup() const;
     void configureCcsMode();
@@ -50,14 +56,6 @@ class ExecutionEnvironment : public ReferenceTrackedObject<ExecutionEnvironment>
     void setMetricsEnabled(bool value) {
         this->metricsEnabled = value;
     }
-    void setExposeSubDevicesAsDevices(bool value) {
-        this->subDevicesAsDevices = value;
-    }
-    void setCombinedDeviceHierarchy(bool value) {
-        this->combinedDeviceHierarchy = value;
-    }
-    bool isExposingSubDevicesAsDevices() const { return this->subDevicesAsDevices; }
-    bool isCombinedDeviceHierarchy() const { return this->combinedDeviceHierarchy; }
     void getErrorDescription(const char **ppString);
     bool getSubDeviceHierarchy(uint32_t index, std::tuple<uint32_t, uint32_t, uint32_t> *subDeviceMap);
     bool areMetricsEnabled() { return this->metricsEnabled; }
@@ -68,8 +66,10 @@ class ExecutionEnvironment : public ReferenceTrackedObject<ExecutionEnvironment>
     bool isFP64EmulationEnabled() const { return fp64EmulationEnabled; }
 
     DirectSubmissionController *initializeDirectSubmissionController();
+    void initializeUnifiedMemoryReuseCleaner();
 
     std::unique_ptr<MemoryManager> memoryManager;
+    std::unique_ptr<UnifiedMemoryReuseCleaner> unifiedMemoryReuseCleaner;
     std::unique_ptr<DirectSubmissionController> directSubmissionController;
     std::unique_ptr<OsEnvironment> osEnvironment;
     std::vector<std::unique_ptr<RootDeviceEnvironment>> rootDeviceEnvironments;
@@ -89,12 +89,12 @@ class ExecutionEnvironment : public ReferenceTrackedObject<ExecutionEnvironment>
     void restoreCcsMode();
     bool metricsEnabled = false;
     bool fp64EmulationEnabled = false;
-    bool subDevicesAsDevices = false;
-    bool combinedDeviceHierarchy = false;
 
+    DeviceHierarchyMode deviceHierarchyMode = DeviceHierarchyMode::composite;
     DebuggingMode debuggingEnabledMode = DebuggingMode::disabled;
     std::unordered_map<uint32_t, uint32_t> rootDeviceNumCcsMap;
     std::mutex initializeDirectSubmissionControllerMutex;
+    std::mutex initializeUnifiedMemoryReuseCleanerMutex;
     std::vector<std::tuple<std::string, uint32_t>> deviceCcsModeVec;
 };
 } // namespace NEO
