@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2019-2024 Intel Corporation
+ * Copyright (C) 2019-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -113,7 +113,7 @@ bool RootDeviceEnvironment::initAilConfiguration() {
         return false;
     }
 
-    ailConfiguration->apply(hwInfo->capabilityTable);
+    ailConfiguration->apply(*hwInfo);
 
     return true;
 }
@@ -158,6 +158,7 @@ CompilerInterface *RootDeviceEnvironment::getCompilerInterface() {
 void RootDeviceEnvironment::initHelpers() {
     initProductHelper();
     initGfxCoreHelper();
+    initializeGfxCoreHelperFromProductHelper();
     initializeGfxCoreHelperFromHwInfo();
     initApiGfxCoreHelper();
     initCompilerProductHelper();
@@ -171,6 +172,12 @@ void RootDeviceEnvironment::initializeGfxCoreHelperFromHwInfo() {
     }
 }
 
+void RootDeviceEnvironment::initializeGfxCoreHelperFromProductHelper() {
+    if (this->productHelper) {
+        gfxCoreHelper->initializeFromProductHelper(*this->productHelper.get());
+    }
+}
+
 void RootDeviceEnvironment::initGfxCoreHelper() {
     if (gfxCoreHelper == nullptr) {
         gfxCoreHelper = GfxCoreHelper::create(this->getHardwareInfo()->platform.eRenderCoreFamily);
