@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2024 Intel Corporation
+ * Copyright (C) 2021-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -12,7 +12,7 @@
 #include "shared/source/helpers/pipeline_select_helper.h"
 #include "shared/source/os_interface/product_helper.h"
 #include "shared/source/os_interface/product_helper.inl"
-#include "shared/source/os_interface/product_helper_bdw_and_later.inl"
+#include "shared/source/os_interface/product_helper_tgllp_and_later.inl"
 
 constexpr static auto gfxProduct = IGFX_ALDERLAKE_P;
 
