@@ -1,22 +1,76 @@
 /*
- * Copyright (C) 2019-2023 Intel Corporation
+ * Copyright (C) 2019-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
  */
 
 #include "shared/source/command_stream/csr_definitions.h"
+#include "shared/source/command_stream/stream_properties.h"
 #include "shared/source/execution_environment/root_device_environment.h"
 #include "shared/source/gen12lp/hw_cmds_base.h"
+#include "shared/source/helpers/flat_batch_buffer_helper.h"
 #include "shared/source/helpers/hw_info.h"
 #include "shared/source/helpers/pipe_control_args.h"
 #include "shared/source/helpers/pipeline_select_helper.h"
-#include "shared/source/helpers/preamble_bdw_and_later.inl"
+#include "shared/source/helpers/preamble_base.inl"
 
 namespace NEO {
 
 using Family = Gen12LpFamily;
 
+template <typename GfxFamily>
+void *PreambleHelper<GfxFamily>::getSpaceForVfeState(LinearStream *pCommandStream,
+                                                     const HardwareInfo &hwInfo,
+                                                     EngineGroupType engineGroupType) {
+    using MEDIA_VFE_STATE = typename GfxFamily::MEDIA_VFE_STATE;
+    addPipeControlBeforeVfeCmd(pCommandStream, &hwInfo, engineGroupType);
+    return pCommandStream->getSpaceForCmd<MEDIA_VFE_STATE>();
+}
+
+template <typename GfxFamily>
+void PreambleHelper<GfxFamily>::programVfeState(void *pVfeState,
+                                                const RootDeviceEnvironment &rootDeviceEnvironment,
+                                                uint32_t scratchSize,
+                                                uint64_t scratchAddress,
+                                                uint32_t maxFrontEndThreads,
+                                                const StreamProperties &streamProperties) {
+    using MEDIA_VFE_STATE = typename GfxFamily::MEDIA_VFE_STATE;
+
+    auto pMediaVfeState = reinterpret_cast<MEDIA_VFE_STATE *>(pVfeState);
+    MEDIA_VFE_STATE cmd = GfxFamily::cmdInitMediaVfeState;
+    cmd.setMaximumNumberOfThreads(maxFrontEndThreads);
+    cmd.setNumberOfUrbEntries(1);
+    cmd.setUrbEntryAllocationSize(PreambleHelper<GfxFamily>::getUrbEntryAllocationSize());
+    cmd.setPerThreadScratchSpace(PreambleHelper<GfxFamily>::getScratchSizeValueToProgramMediaVfeState(scratchSize));
+    cmd.setStackSize(PreambleHelper<GfxFamily>::getScratchSizeValueToProgramMediaVfeState(scratchSize));
+    uint32_t lowAddress = static_cast<uint32_t>(0xFFFFFFFF & scratchAddress);
+    uint32_t highAddress = static_cast<uint32_t>(0xFFFFFFFF & (scratchAddress >> 32));
+    cmd.setScratchSpaceBasePointer(lowAddress);
+    cmd.setScratchSpaceBasePointerHigh(highAddress);
+
+    appendProgramVFEState(rootDeviceEnvironment, streamProperties, &cmd);
+    *pMediaVfeState = cmd;
+}
+
+template <typename GfxFamily>
+uint64_t PreambleHelper<GfxFamily>::getScratchSpaceAddressOffsetForVfeState(LinearStream *pCommandStream, void *pVfeState) {
+    using MEDIA_VFE_STATE = typename GfxFamily::MEDIA_VFE_STATE;
+    return static_cast<uint64_t>(reinterpret_cast<uintptr_t>(pVfeState) -
+                                 reinterpret_cast<uintptr_t>(pCommandStream->getCpuBase()) +
+                                 MEDIA_VFE_STATE::PATCH_CONSTANTS::SCRATCHSPACEBASEPOINTER_BYTEOFFSET);
+}
+
+template <typename GfxFamily>
+size_t PreambleHelper<GfxFamily>::getVFECommandsSize() {
+    using MEDIA_VFE_STATE = typename GfxFamily::MEDIA_VFE_STATE;
+    return sizeof(MEDIA_VFE_STATE) + sizeof(PIPE_CONTROL);
+}
+
+template <typename GfxFamily>
+void PreambleHelper<GfxFamily>::setSingleSliceDispatchMode(void *cmd, bool enable) {
+}
+
 template <>
 uint32_t PreambleHelper<Family>::getL3Config(const HardwareInfo &hwInfo, bool useSLM) {
     uint32_t l3Config = 0;
@@ -78,7 +132,7 @@ template <>
 void PreambleHelper<Family>::addPipeControlBeforeVfeCmd(LinearStream *pCommandStream, const HardwareInfo *hwInfo, EngineGroupType engineGroupType) {
     PipeControlArgs args = {};
     if (hwInfo->workaroundTable.flags.waSendMIFLUSHBeforeVFE) {
-        if (engineGroupType != EngineGroupType::Compute) {
+        if (engineGroupType != EngineGroupType::compute) {
             args.renderTargetCacheFlushEnable = true;
             args.depthCacheFlushEnable = true;
             args.depthStallEnable = true;
@@ -90,7 +144,7 @@ void PreambleHelper<Family>::addPipeControlBeforeVfeCmd(LinearStream *pCommandSt
 }
 
 template <>
-void PreambleHelper<Family>::programL3(LinearStream *pCommandStream, uint32_t l3Config) {
+void PreambleHelper<Family>::programL3(LinearStream *pCommandStream, uint32_t l3Config, bool isBcs) {
 }
 
 template <>
@@ -100,15 +154,15 @@ uint32_t PreambleHelper<Family>::getUrbEntryAllocationSize() {
 
 template <>
 void PreambleHelper<Family>::appendProgramVFEState(const RootDeviceEnvironment &rootDeviceEnvironment, const StreamProperties &streamProperties, void *cmd) {
-    VFE_STATE_TYPE *mediaVfeState = static_cast<VFE_STATE_TYPE *>(cmd);
+    FrontEndStateCommand *mediaVfeState = static_cast<FrontEndStateCommand *>(cmd);
     bool disableEUFusion = streamProperties.frontEndState.disableEUFusion.value == 1;
     auto &gfxCoreHelper = rootDeviceEnvironment.getHelper<GfxCoreHelper>();
     auto &hwInfo = *rootDeviceEnvironment.getHardwareInfo();
     if (!gfxCoreHelper.isFusedEuDispatchEnabled(hwInfo, disableEUFusion)) {
         mediaVfeState->setDisableSlice0Subslice2(true);
     }
-    if (DebugManager.flags.MediaVfeStateMaxSubSlices.get() != -1) {
-        mediaVfeState->setMaximumNumberOfDualSubslices(DebugManager.flags.MediaVfeStateMaxSubSlices.get());
+    if (debugManager.flags.MediaVfeStateMaxSubSlices.get() != -1) {
+        mediaVfeState->setMaximumNumberOfDualSubslices(debugManager.flags.MediaVfeStateMaxSubSlices.get());
     }
 }
 
