@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2024 Intel Corporation
+ * Copyright (C) 2018-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -8,6 +8,7 @@
 #pragma once
 #include "shared/source/built_ins/sip_kernel_type.h"
 #include "shared/source/helpers/definitions/engine_group_types.h"
+#include "shared/source/helpers/device_hierarchy_mode.h"
 #include "shared/source/helpers/engine_node_helper.h"
 #include "shared/source/helpers/options.h"
 #include "shared/source/utilities/stackvec.h"
@@ -49,11 +50,6 @@ class AILConfiguration;
 using EngineInstancesContainer = StackVec<EngineTypeUsage, 32>;
 using GfxCoreHelperCreateFunctionType = std::unique_ptr<GfxCoreHelper> (*)();
 
-extern const char *deviceHierarchyComposite;
-extern const char *deviceHierarchyFlat;
-extern const char *deviceHierarchyCombined;
-extern const char *deviceHierarchyUnk;
-
 class GfxCoreHelper {
   public:
     static std::unique_ptr<GfxCoreHelper> create(const GFXCORE_FAMILY gfxCoreFamily);
@@ -171,7 +167,7 @@ class GfxCoreHelper {
     virtual bool isRelaxedOrderingSupported() const = 0;
     virtual uint32_t calculateNumThreadsPerThreadGroup(uint32_t simd, uint32_t totalWorkItems, uint32_t grfCount, bool isHwLocalIdGeneration, const RootDeviceEnvironment &rootDeviceEnvironment) const = 0;
     virtual uint32_t overrideMaxWorkGroupSize(uint32_t maxWG) const = 0;
-    virtual char const *getDefaultDeviceHierarchy() const = 0;
+    virtual DeviceHierarchyMode getDefaultDeviceHierarchy() const = 0;
     static bool isWorkaroundRequired(uint32_t lowestSteppingWithBug, uint32_t steppingWithFix, const HardwareInfo &hwInfo, const ProductHelper &productHelper);
 
     virtual bool areSecondaryContextsSupported() const = 0;
@@ -180,6 +176,7 @@ class GfxCoreHelper {
     virtual void adjustCopyEngineRegularContextCount(const size_t enginesCount, uint32_t &contextCount) const = 0;
     virtual aub_stream::EngineType getDefaultHpCopyEngine(const HardwareInfo &hwInfo) const = 0;
     virtual void initializeDefaultHpCopyEngine(const HardwareInfo &hwInfo) = 0;
+    virtual void initializeFromProductHelper(const ProductHelper &productHelper) = 0;
 
     virtual bool is48ResourceNeededForCmdBuffer() const = 0;
     virtual uint32_t getKernelPrivateMemSize(const KernelDescriptor &kernelDescriptor) const = 0;
@@ -408,7 +405,7 @@ class GfxCoreHelperHw : public GfxCoreHelper {
     bool isRelaxedOrderingSupported() const override;
     uint32_t calculateNumThreadsPerThreadGroup(uint32_t simd, uint32_t totalWorkItems, uint32_t grfCount, bool isHwLocalIdGeneration, const RootDeviceEnvironment &rootDeviceEnvironment) const override;
     uint32_t overrideMaxWorkGroupSize(uint32_t maxWG) const override;
-    char const *getDefaultDeviceHierarchy() const override;
+    DeviceHierarchyMode getDefaultDeviceHierarchy() const override;
 
     bool areSecondaryContextsSupported() const override;
     uint32_t getContextGroupContextsCount() const override;
@@ -416,6 +413,7 @@ class GfxCoreHelperHw : public GfxCoreHelper {
     void adjustCopyEngineRegularContextCount(const size_t enginesCount, uint32_t &contextCount) const override;
     aub_stream::EngineType getDefaultHpCopyEngine(const HardwareInfo &hwInfo) const override;
     void initializeDefaultHpCopyEngine(const HardwareInfo &hwInfo) override;
+    void initializeFromProductHelper(const ProductHelper &productHelper) override;
 
     bool is48ResourceNeededForCmdBuffer() const override;
 
@@ -442,6 +440,7 @@ class GfxCoreHelperHw : public GfxCoreHelper {
 
   protected:
     aub_stream::EngineType hpCopyEngineType = aub_stream::EngineType::NUM_ENGINES;
+    bool secondaryContextsEnabled = false;
 
     static const AuxTranslationMode defaultAuxTranslationMode;
     GfxCoreHelperHw() = default;
