@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2023-2024 Intel Corporation
+ * Copyright (C) 2023-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -30,7 +30,7 @@ class DeviceAllocNodeType {
 
     static constexpr size_t defaultAllocatorTagCount = 128;
 
-    static constexpr AllocationType getAllocationType() { return deviceAlloc ? AllocationType::timestampPacketTagBuffer : NEO::AllocationType::bufferHostMemory; }
+    static constexpr AllocationType getAllocationType() { return deviceAlloc ? NEO::AllocationType::timestampPacketTagBuffer : NEO::AllocationType::bufferHostMemory; }
 
     static constexpr TagNodeType getTagNodeType() { return TagNodeType::counter64b; }
 
@@ -139,7 +139,8 @@ enum class PatchCmdType {
     lri64b,
     sdi,
     semaphore,
-    walker
+    walker,
+    pipeControl
 };
 
 template <typename GfxFamily>
@@ -168,6 +169,9 @@ struct PatchCmd {
         case PatchCmdType::lri64b:
             patchLri64b(appendCounterValue);
             break;
+        case PatchCmdType::pipeControl:
+            patchPipeControl(appendCounterValue);
+            break;
         default:
             UNRECOVERABLE_IF(true);
             break;
@@ -214,6 +218,11 @@ struct PatchCmd {
 
     void patchComputeWalker(uint64_t appendCounterValue);
 
+    void patchPipeControl(uint64_t appendCounterValue) {
+        auto pcCmd = reinterpret_cast<typename GfxFamily::PIPE_CONTROL *>(cmd1);
+        pcCmd->setImmediateData(static_cast<uint64_t>(baseCounterValue + appendCounterValue));
+    }
+
     void patchLri64b(uint64_t appendCounterValue) {
         if (isExternalDependency()) {
             appendCounterValue = InOrderPatchCommandHelpers::getAppendCounterValue(*inOrderExecInfo);
