@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2019-2024 Intel Corporation
+ * Copyright (C) 2019-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -16,10 +16,12 @@
 #include "shared/source/helpers/api_specific_config.h"
 #include "shared/source/helpers/basic_math.h"
 #include "shared/source/helpers/gfx_core_helper.h"
+#include "shared/source/helpers/hw_info.h"
 #include "shared/source/helpers/memory_properties_helpers.h"
 #include "shared/source/memory_manager/allocation_properties.h"
 #include "shared/source/memory_manager/compression_selector.h"
 #include "shared/source/memory_manager/memory_manager.h"
+#include "shared/source/memory_manager/unified_memory_reuse_cleaner.h"
 #include "shared/source/os_interface/os_context.h"
 #include "shared/source/os_interface/product_helper.h"
 #include "shared/source/page_fault_manager/cpu_page_fault_manager.h"
@@ -62,7 +64,7 @@ bool SVMAllocsManager::SvmAllocationCache::insert(size_t size, void *ptr, SvmAll
     if (auto device = svmData->device) {
         auto lock = device->obtainAllocationsReuseLock();
         const auto usedSize = device->getAllocationsSavedForReuseSize();
-        if (size + usedSize > this->maxSize) {
+        if (size + usedSize > device->getMaxAllocationsSavedForReuseSize()) {
             return false;
         }
         device->recordAllocationSaveForReuse(size);
@@ -110,15 +112,15 @@ void *SVMAllocsManager::SvmAllocationCache::get(size_t size, const UnifiedMemory
             break;
         }
         void *allocationPtr = allocationIter->allocation;
-        SvmAllocationData *svmAllocData = svmAllocsManager->getSVMAlloc(allocationPtr);
-        UNRECOVERABLE_IF(!svmAllocData);
-        if (svmAllocData->device == unifiedMemoryProperties.device &&
-            svmAllocData->allocationFlagsProperty.allFlags == unifiedMemoryProperties.allocationFlags.allFlags &&
-            svmAllocData->allocationFlagsProperty.allAllocFlags == unifiedMemoryProperties.allocationFlags.allAllocFlags &&
-            false == isInUse(svmAllocData)) {
-            if (svmAllocData->device) {
-                auto lock = svmAllocData->device->obtainAllocationsReuseLock();
-                svmAllocData->device->recordAllocationGetFromReuse(allocationIter->allocationSize);
+        SvmAllocationData *svmData = svmAllocsManager->getSVMAlloc(allocationPtr);
+        UNRECOVERABLE_IF(nullptr == svmData);
+        if (svmData->device == unifiedMemoryProperties.device &&
+            svmData->allocationFlagsProperty.allFlags == unifiedMemoryProperties.allocationFlags.allFlags &&
+            svmData->allocationFlagsProperty.allAllocFlags == unifiedMemoryProperties.allocationFlags.allAllocFlags &&
+            false == isInUse(svmData)) {
+            if (svmData->device) {
+                auto lock = svmData->device->obtainAllocationsReuseLock();
+                svmData->device->recordAllocationGetFromReuse(allocationIter->allocationSize);
             } else {
                 auto lock = memoryManager->obtainHostAllocationsReuseLock();
                 memoryManager->recordHostAllocationGetFromReuse(allocationIter->allocationSize);
@@ -134,7 +136,7 @@ void SVMAllocsManager::SvmAllocationCache::trim() {
     std::lock_guard<std::mutex> lock(this->mtx);
     for (auto &cachedAllocationInfo : this->allocations) {
         SvmAllocationData *svmData = svmAllocsManager->getSVMAlloc(cachedAllocationInfo.allocation);
-        DEBUG_BREAK_IF(nullptr == svmData);
+        UNRECOVERABLE_IF(nullptr == svmData);
         if (svmData->device) {
             auto lock = svmData->device->obtainAllocationsReuseLock();
             svmData->device->recordAllocationGetFromReuse(cachedAllocationInfo.allocationSize);
@@ -147,6 +149,38 @@ void SVMAllocsManager::SvmAllocationCache::trim() {
     this->allocations.clear();
 }
 
+void SVMAllocsManager::SvmAllocationCache::cleanup() {
+    if (this->memoryManager) {
+        if (auto usmReuseCleaner = this->memoryManager->peekExecutionEnvironment().unifiedMemoryReuseCleaner.get()) {
+            usmReuseCleaner->unregisterSvmAllocationCache(this);
+        }
+    }
+    this->trim();
+}
+
+void SVMAllocsManager::SvmAllocationCache::trimOldAllocs(std::chrono::high_resolution_clock::time_point trimTimePoint) {
+    std::lock_guard<std::mutex> lock(this->mtx);
+    for (auto allocationIter = allocations.begin();
+         allocationIter != allocations.end();) {
+        if (allocationIter->saveTime > trimTimePoint) {
+            ++allocationIter;
+            continue;
+        }
+        void *allocationPtr = allocationIter->allocation;
+        SvmAllocationData *svmData = svmAllocsManager->getSVMAlloc(allocationPtr);
+        UNRECOVERABLE_IF(nullptr == svmData);
+        if (svmData->device) {
+            auto lock = svmData->device->obtainAllocationsReuseLock();
+            svmData->device->recordAllocationGetFromReuse(allocationIter->allocationSize);
+        } else {
+            auto lock = memoryManager->obtainHostAllocationsReuseLock();
+            memoryManager->recordHostAllocationGetFromReuse(allocationIter->allocationSize);
+        }
+        svmAllocsManager->freeSVMAllocImpl(allocationIter->allocation, FreePolicyType::defer, svmData);
+        allocationIter = allocations.erase(allocationIter);
+    }
+}
+
 SvmAllocationData *SVMAllocsManager::MapBasedAllocationTracker::get(const void *ptr) {
     if (allocations.size() == 0) {
         return nullptr;
@@ -261,7 +295,16 @@ void *SVMAllocsManager::createSVMAlloc(size_t size, const SvmAllocationPropertie
 
 void *SVMAllocsManager::createHostUnifiedMemoryAllocation(size_t size,
                                                           const UnifiedMemoryProperties &memoryProperties) {
-    constexpr size_t pageSizeForAlignment = MemoryConstants::pageSize;
+    bool isDiscrete = false;
+    if (size >= MemoryConstants::pageSize2M && !debugManager.flags.NEO_CAL_ENABLED.get()) {
+        for (const auto rootDeviceIndex : memoryProperties.rootDeviceIndices) {
+            isDiscrete |= !this->memoryManager->peekExecutionEnvironment().rootDeviceEnvironments[rootDeviceIndex]->getHardwareInfo()->capabilityTable.isIntegratedDevice;
+            if (isDiscrete) {
+                break;
+            }
+        }
+    }
+    const size_t pageSizeForAlignment = isDiscrete ? MemoryConstants::pageSize2M : MemoryConstants::pageSize;
     const size_t alignedSize = alignUp<size_t>(size, pageSizeForAlignment);
 
     bool compressionEnabled = false;
@@ -622,6 +665,11 @@ void SVMAllocsManager::freeSVMAllocDeferImpl() {
     }
 }
 
+void SVMAllocsManager::cleanupUSMAllocCaches() {
+    this->usmDeviceAllocationsCache.cleanup();
+    this->usmHostAllocationsCache.cleanup();
+}
+
 void SVMAllocsManager::trimUSMDeviceAllocCache() {
     this->usmDeviceAllocationsCache.trim();
 }
@@ -760,19 +808,14 @@ void SVMAllocsManager::freeZeroCopySvmAllocation(SvmAllocationData *svmData) {
 }
 
 void SVMAllocsManager::initUsmDeviceAllocationsCache(Device &device) {
-    const auto totalDeviceMemory = device.getGlobalMemorySize(static_cast<uint32_t>(device.getDeviceBitfield().to_ulong()));
-    auto ailConfiguration = device.getAilConfigurationHelper();
-    const bool limitDeviceMemoryForReuse = ailConfiguration && ailConfiguration->limitAmountOfDeviceMemoryForRecycling();
-    auto fractionOfTotalMemoryForRecycling = limitDeviceMemoryForReuse ? 0 : 0.08;
-    if (debugManager.flags.ExperimentalEnableDeviceAllocationCache.get() != -1) {
-        fractionOfTotalMemoryForRecycling = 0.01 * std::min(100, debugManager.flags.ExperimentalEnableDeviceAllocationCache.get());
-    }
-    this->usmDeviceAllocationsCache.maxSize = static_cast<size_t>(fractionOfTotalMemoryForRecycling * totalDeviceMemory);
-    if (this->usmDeviceAllocationsCache.maxSize > 0u) {
+    if (device.getMaxAllocationsSavedForReuseSize() > 0u) {
         this->usmDeviceAllocationsCache.allocations.reserve(128u);
+        this->usmDeviceAllocationsCache.svmAllocsManager = this;
+        this->usmDeviceAllocationsCache.memoryManager = memoryManager;
+        if (auto usmReuseCleaner = device.getExecutionEnvironment()->unifiedMemoryReuseCleaner.get()) {
+            usmReuseCleaner->registerSvmAllocationCache(&this->usmDeviceAllocationsCache);
+        }
     }
-    this->usmDeviceAllocationsCache.svmAllocsManager = this;
-    this->usmDeviceAllocationsCache.memoryManager = memoryManager;
 }
 
 void SVMAllocsManager::initUsmHostAllocationsCache() {
@@ -784,9 +827,12 @@ void SVMAllocsManager::initUsmHostAllocationsCache() {
     this->usmHostAllocationsCache.maxSize = static_cast<size_t>(fractionOfTotalMemoryForRecycling * totalSystemMemory);
     if (this->usmHostAllocationsCache.maxSize > 0u) {
         this->usmHostAllocationsCache.allocations.reserve(128u);
+        this->usmHostAllocationsCache.svmAllocsManager = this;
+        this->usmHostAllocationsCache.memoryManager = memoryManager;
+        if (auto usmReuseCleaner = this->memoryManager->peekExecutionEnvironment().unifiedMemoryReuseCleaner.get()) {
+            usmReuseCleaner->registerSvmAllocationCache(&this->usmHostAllocationsCache);
+        }
     }
-    this->usmHostAllocationsCache.svmAllocsManager = this;
-    this->usmHostAllocationsCache.memoryManager = memoryManager;
 }
 
 void SVMAllocsManager::initUsmAllocationsCaches(Device &device) {
@@ -795,6 +841,7 @@ void SVMAllocsManager::initUsmAllocationsCaches(Device &device) {
         this->usmDeviceAllocationsCacheEnabled = !!debugManager.flags.ExperimentalEnableDeviceAllocationCache.get();
     }
     if (this->usmDeviceAllocationsCacheEnabled) {
+        device.getExecutionEnvironment()->initializeUnifiedMemoryReuseCleaner();
         this->initUsmDeviceAllocationsCache(device);
     }
 
@@ -803,6 +850,7 @@ void SVMAllocsManager::initUsmAllocationsCaches(Device &device) {
         this->usmHostAllocationsCacheEnabled = !!debugManager.flags.ExperimentalEnableHostAllocationCache.get();
     }
     if (this->usmHostAllocationsCacheEnabled) {
+        device.getExecutionEnvironment()->initializeUnifiedMemoryReuseCleaner();
         this->initUsmHostAllocationsCache();
     }
 }
