@@ -30,7 +30,7 @@ MemoryOperationsStatus DrmMemoryOperationsHandlerBind::makeResident(Device *devi
     auto &engines = device->getAllEngines();
     MemoryOperationsStatus result = MemoryOperationsStatus::success;
     for (const auto &engine : engines) {
-        engine.commandStreamReceiver->initializeResources(false);
+        engine.commandStreamReceiver->initializeResources(false, device->getPreemptionMode());
         result = this->makeResidentWithinOsContext(engine.osContext, gfxAllocations, false, forcePagingFence);
         if (result != MemoryOperationsStatus::success) {
             break;
@@ -204,7 +204,7 @@ MemoryOperationsStatus DrmMemoryOperationsHandlerBind::evictUnusedAllocationsImp
                         evict = false;
                         break;
                     }
-                    if (waitForCompletion) {
+                    if (waitForCompletion && engine.commandStreamReceiver->isInitialized()) {
                         const auto waitStatus = engine.commandStreamReceiver->waitForCompletionWithTimeout(WaitParams{false, false, false, 0}, engine.commandStreamReceiver->peekLatestFlushedTaskCount());
                         if (waitStatus == WaitStatus::gpuHang) {
                             return MemoryOperationsStatus::gpuHangDetectedDuringOperation;
