@@ -151,6 +151,8 @@ class Drm : public DriverModel {
 
     void setDirectSubmissionActive(bool value) { this->directSubmissionActive = value; }
     bool isDirectSubmissionActive() const { return this->directSubmissionActive; }
+    MOCKABLE_VIRTUAL void setSharedSystemAllocEnable(bool value) { this->sharedSystemAllocEnable = value; }
+    MOCKABLE_VIRTUAL bool isSharedSystemAllocEnabled() const { return this->sharedSystemAllocEnable; }
 
     MOCKABLE_VIRTUAL bool isSetPairAvailable();
     MOCKABLE_VIRTUAL bool getSetPairAvailable() { return setPairAvailable; }
@@ -215,8 +217,8 @@ class Drm : public DriverModel {
     std::string getPciPath() { return hwDeviceId->getPciPath(); }
     std::string getDeviceNode() { return hwDeviceId->getDeviceNode(); }
 
+    std::pair<uint64_t, uint64_t> getFenceAddressAndValToWait(uint32_t vmHandleId, bool isLocked);
     void waitForBind(uint32_t vmHandleId);
-    void waitForBindGivenFenceVal(uint32_t vmHandleId, uint64_t fenceValToWait);
     uint64_t getNextFenceVal(uint32_t vmHandleId) { return fenceVal[vmHandleId] + 1; }
     void incFenceVal(uint32_t vmHandleId) { fenceVal[vmHandleId]++; }
     uint64_t *getFenceAddr(uint32_t vmHandleId) { return &pagingFence[vmHandleId]; }
@@ -348,6 +350,7 @@ class Drm : public DriverModel {
     bool requirePerContextVM = false;
     bool bindAvailable = false;
     bool directSubmissionActive = false;
+    bool sharedSystemAllocEnable = false;
     bool setPairAvailable = false;
     bool chunkingAvailable = false;
     uint32_t chunkingMode = 0;
