@@ -108,41 +108,41 @@ void OsContextLinux::waitForPagingFence() {
 }
 
 void OsContextLinux::waitForBind(uint32_t drmIterator) {
-    if (drm.isPerContextVMRequired()) {
-        if (pagingFence[drmIterator] >= fenceVal[drmIterator]) {
-            return;
-        }
-        auto lock = drm.lockBindFenceMutex();
-        auto fenceAddress = castToUint64(&this->pagingFence[drmIterator]);
-        auto fenceValue = this->fenceVal[drmIterator];
-        lock.unlock();
 
-        drm.waitUserFence(0u, fenceAddress, fenceValue, Drm::ValueWidth::u64, -1, drm.getIoctlHelper()->getWaitUserFenceSoftFlag(), false, NEO::InterruptId::notUsed, nullptr);
+    auto fenceAddressAndValToWait = getFenceAddressAndValToWait(drmIterator, false);
 
-    } else {
-        drm.waitForBind(drmIterator);
+    const auto fenceAddressToWait = fenceAddressAndValToWait.first;
+    const auto fenceValToWait = fenceAddressAndValToWait.second;
+
+    if (fenceAddressToWait != 0u) {
+        drm.waitUserFence(0u, fenceAddressToWait, fenceValToWait, Drm::ValueWidth::u64, -1, drm.getIoctlHelper()->getWaitUserFenceSoftFlag(), false, NEO::InterruptId::notUsed, nullptr);
     }
 }
 
-void OsContextLinux::waitForPagingFenceGivenFenceVal(uint64_t fenceValToWait) {
-    for (auto drmIterator = 0u; drmIterator < this->deviceBitfield.size(); drmIterator++) {
-        if (this->deviceBitfield.test(drmIterator)) {
-            this->waitForBindGivenFenceVal(drmIterator, fenceValToWait);
-        }
-    }
-}
-
-void OsContextLinux::waitForBindGivenFenceVal(uint32_t drmIterator, uint64_t fenceValToWait) {
+[[nodiscard]] std::pair<uint64_t, uint64_t> OsContextLinux::getFenceAddressAndValToWait(uint32_t vmHandleId, bool isLocked) {
     if (drm.isPerContextVMRequired()) {
-        if (pagingFence[drmIterator] >= fenceValToWait) {
-            return;
+        std::pair<uint64_t, uint64_t> fenceAddressAndValToWait = std::make_pair(0, 0);
+        std::unique_lock<std::mutex> lock;
+
+        if (!isLocked) {
+            lock = drm.lockBindFenceMutex();
         }
 
-        auto fenceAddress = castToUint64(&this->pagingFence[drmIterator]);
-        drm.waitUserFence(0u, fenceAddress, fenceValToWait, Drm::ValueWidth::u64, -1, drm.getIoctlHelper()->getWaitUserFenceSoftFlag(), false, NEO::InterruptId::notUsed, nullptr);
+        if (!(pagingFence[vmHandleId] >= fenceVal[vmHandleId])) {
+
+            auto fenceAddress = castToUint64(&this->pagingFence[vmHandleId]);
+            auto fenceValue = this->fenceVal[vmHandleId];
+            fenceAddressAndValToWait = std::make_pair(fenceAddress, fenceValue);
+        }
+
+        if (!isLocked) {
+            lock.unlock();
+        }
+
+        return fenceAddressAndValToWait;
 
     } else {
-        drm.waitForBindGivenFenceVal(drmIterator, fenceValToWait);
+        return drm.getFenceAddressAndValToWait(vmHandleId, isLocked);
     }
 }
 
