@@ -29,8 +29,8 @@ class OsContextLinux : public OsContext {
     const std::vector<uint32_t> &getDrmVmIds() const { return drmVmIds; }
     bool isDirectSubmissionSupported() const override;
     Drm &getDrm() const;
+    virtual std::pair<uint64_t, uint64_t> getFenceAddressAndValToWait(uint32_t vmHandleId, bool isLocked);
     virtual void waitForPagingFence();
-    virtual void waitForPagingFenceGivenFenceVal(uint64_t fenceValToWait);
     static OsContext *create(OSInterface *osInterface, uint32_t rootDeviceIndex, uint32_t contextId, const EngineDescriptor &engineDescriptor);
     void reInitializeContext() override;
     void setHangDetected() {
@@ -46,7 +46,6 @@ class OsContextLinux : public OsContext {
     void incFenceVal(uint32_t deviceIndex) { fenceVal[deviceIndex]++; }
     uint64_t *getFenceAddr(uint32_t deviceIndex) { return &pagingFence[deviceIndex]; }
     void waitForBind(uint32_t drmIterator);
-    void waitForBindGivenFenceVal(uint32_t drmIterator, uint64_t fenceValToWait);
 
   protected:
     bool initializeContext(bool allocateInterrupt) override;
