@@ -1,11 +1,12 @@
 /*
- * Copyright (C) 2019-2023 Intel Corporation
+ * Copyright (C) 2019-2024 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
  */
 
 #pragma once
+#include "shared/source/helpers/non_copyable_or_moveable.h"
 #include "shared/source/os_interface/os_library.h"
 
 #define UMDF_USING_NTSTATUS
@@ -14,12 +15,12 @@
 namespace NEO {
 namespace Windows {
 
-class OsLibrary : public NEO::OsLibrary {
+class OsLibrary : public NEO::OsLibrary, NEO::NonCopyableOrMovableClass {
   private:
     HMODULE handle;
 
   public:
-    OsLibrary(const std::string &name, std::string *errorValue);
+    OsLibrary(const OsLibraryCreateProperties &properties);
     ~OsLibrary();
 
     bool isLoaded();
@@ -31,8 +32,11 @@ class OsLibrary : public NEO::OsLibrary {
   protected:
     HMODULE loadDependency(const std::string &dependencyFileName) const;
 
+    static decltype(&GetModuleHandleA) getModuleHandleA;
     static decltype(&LoadLibraryExA) loadLibraryExA;
     static decltype(&GetModuleFileNameA) getModuleFileNameA;
+    static decltype(&FreeLibrary) freeLibrary;
+    bool selfOpen = false;
 };
 } // namespace Windows
 } // namespace NEO
