@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2024 Intel Corporation
+ * Copyright (C) 2021-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -16,8 +16,6 @@
 #include "shared/source/os_interface/linux/sys_calls.h"
 #include "shared/source/os_interface/product_helper.h"
 #include "shared/source/os_interface/product_helper.inl"
-#include "shared/source/os_interface/product_helper_dg2_and_later.inl"
-#include "shared/source/os_interface/product_helper_xehp_and_later.inl"
 #include "shared/source/utilities/directory.h"
 #include "shared/source/xe_hpc_core/hw_cmds_pvc.h"
 
@@ -83,6 +81,11 @@ bool ProductHelperHw<gfxProduct>::isKmdMigrationSupported() const {
     return false;
 }
 
+template <>
+bool ProductHelperHw<gfxProduct>::isDisableScratchPagesSupported() const {
+    return true;
+}
+
 } // namespace NEO
 
 #include "shared/source/xe_hpc_core/linux/product_helper_xe_hpc_core.inl"
