@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2024 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -47,7 +47,16 @@ UltDeviceFactory::UltDeviceFactory(uint32_t rootDevicesCount, uint32_t subDevice
         pCreatedDevice->incRefInternal();
         if (pCreatedDevice->getNumSubDevices() > 1) {
             for (uint32_t i = 0; i < pCreatedDevice->getNumSubDevices(); i++) {
-                this->subDevices.push_back(static_cast<SubDevice *>(pCreatedDevice->getSubDevice(i)));
+                auto *pDevice = static_cast<SubDevice *>(pCreatedDevice->getSubDevice(i));
+                this->subDevices.push_back(pDevice);
+            }
+        }
+        if (pCreatedDevice->getPreemptionMode() == NEO::PreemptionMode::MidThread) {
+            for (auto &engine : pCreatedDevice->getAllEngines()) {
+                NEO::CommandStreamReceiver *csr = engine.commandStreamReceiver;
+                if (!csr->getPreemptionAllocation()) {
+                    csr->createPreemptionAllocation();
+                }
             }
         }
         this->rootDevices.push_back(static_cast<MockDevice *>(pCreatedDevice.release()));
@@ -60,7 +69,7 @@ UltDeviceFactory::~UltDeviceFactory() {
     }
 }
 
-void UltDeviceFactory::prepareDeviceEnvironments(ExecutionEnvironment &executionEnvironment, uint32_t rootDevicesCount) {
+bool UltDeviceFactory::prepareDeviceEnvironments(ExecutionEnvironment &executionEnvironment, uint32_t rootDevicesCount) {
     uint32_t numRootDevices = rootDevicesCount;
     executionEnvironment.prepareRootDeviceEnvironments(numRootDevices);
     for (auto i = 0u; i < numRootDevices; i++) {
@@ -72,8 +81,12 @@ void UltDeviceFactory::prepareDeviceEnvironments(ExecutionEnvironment &execution
         executionEnvironment.rootDeviceEnvironments[i]->memoryOperationsInterface = std::make_unique<MockMemoryOperations>();
     }
     executionEnvironment.parseAffinityMask();
-    executionEnvironment.calculateMaxOsContextCount();
-    DeviceFactory::createMemoryManagerFunc(executionEnvironment);
+    auto retVal = executionEnvironment.rootDeviceEnvironments.size();
+    if (retVal) {
+        executionEnvironment.calculateMaxOsContextCount();
+        DeviceFactory::createMemoryManagerFunc(executionEnvironment);
+    }
+    return retVal;
 }
 bool UltDeviceFactory::initializeMemoryManager(ExecutionEnvironment &executionEnvironment) {
     if (executionEnvironment.memoryManager == nullptr) {
