@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2019-2024 Intel Corporation
+ * Copyright (C) 2019-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -91,6 +91,10 @@ void DrmMemoryManagerFixture::tearDown() {
         enginesCount += engineContainer.size();
     }
 
+    for (auto &engineContainer : memoryManager->secondaryEngines) {
+        enginesCount -= engineContainer.size();
+    }
+
     mock->ioctlExpected.contextDestroy = enginesCount;
     mock->ioctlExpected.gemClose = enginesCount;
     mock->ioctlExpected.gemWait = enginesCount;
