@@ -7,13 +7,17 @@
 
 #pragma once
 
+#include "shared/source/helpers/common_types.h"
 #include "shared/source/os_interface/linux/cache_info.h"
 
 namespace NEO {
 
 struct MockCacheInfo : public CacheInfo {
-    using CacheInfo::cacheRegionsReserved;
+    using CacheInfo::freeRegion;
+    using CacheInfo::getRegion;
     using CacheInfo::isRegionReserved;
+    using CacheInfo::reservedCacheRegionsSize;
+    using CacheInfo::reserveRegion;
 
     MockCacheInfo(IoctlHelper &ioctlHelper, size_t maxReservationCacheSize, uint32_t maxReservationNumCacheRegions, uint16_t maxReservationNumWays)
         : CacheInfo(ioctlHelper, maxReservationCacheSize, maxReservationNumCacheRegions, maxReservationNumWays) {}
