@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2024 Intel Corporation
+ * Copyright (C) 2020-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -846,11 +846,15 @@ HWTEST2_F(CommandEncoderTests, whenAskingForImplicitScalingValuesThenAlwaysRetur
         &ptr,                    // outWalkerPtr
         RequiredPartitionDim::x, // requiredPartitionDim
         partitionCount,          // partitionCount
+        1,                       // workgroupSize
+        1,                       // threadGroupCount
+        1,                       // maxWgCountPerTile
         false,                   // useSecondaryBatchBuffer
         false,                   // apiSelfCleanup
         false,                   // dcFlush
         false,                   // forceExecutionOnSingleTile
-        false};                  // blockDispatchToCommandBuffer
+        false,                   // blockDispatchToCommandBuffer
+        false};                  // isRequiredDispatchWorkGroupOrder
 
     ImplicitScalingDispatch<FamilyType>::dispatchCommands(linearStream, walkerCmd, deviceBitField, args);
     EXPECT_EQ(0u, linearStream.getUsed());
