@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2022 Intel Corporation
+ * Copyright (C) 2022-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -40,8 +40,8 @@ struct GdiInterfaceLoggingBaseFixture {
 struct GdiInterfaceLoggingNoInitFixture : public GdiInterfaceLoggingBaseFixture {
     void setUp() {
         GdiInterfaceLoggingBaseFixture::setUp();
-        openFile = DebugManager.flags.LogGdiCallsToFile.get();
-        DebugManager.flags.LogGdiCalls.set(true);
+        openFile = debugManager.flags.LogGdiCallsToFile.get();
+        debugManager.flags.LogGdiCalls.set(true);
         mockVfptrinfUseStdioFunctionBackup = std::make_unique<VariableBackup<bool>>(&NEO::IoFunctions::mockVfptrinfUseStdioFunction, !openFile);
     }
 
@@ -81,7 +81,7 @@ struct GdiInterfaceLoggingFixture : public GdiInterfaceLoggingNoInitFixture {
 
 struct GdiInterfaceLoggingToFileFixture : public GdiInterfaceLoggingFixture {
     void setUp() {
-        DebugManager.flags.LogGdiCallsToFile.set(true);
+        debugManager.flags.LogGdiCallsToFile.set(true);
         GdiInterfaceLoggingFixture::setUp();
     }
 
@@ -1037,6 +1037,30 @@ TEST_F(GdiInterfaceLoggingTest, WhenGdiLoggingIsEnabledWhenLoggingOpenSyncObject
     EXPECT_STREQ(expectedOutput.str().c_str(), logExitStr.c_str());
 }
 
+TEST_F(GdiInterfaceLoggingTest, WhenGdiLoggingIsEnabledWhenLoggingOpenSyncObjectNtHandleFromNameThenExpectCorrectStrings) {
+    D3DKMT_OPENSYNCOBJECTNTHANDLEFROMNAME param = {};
+
+    std::stringstream expectedOutput;
+    expectedOutput << logEnterBegin
+                   << "D3DKMT_OPENSYNCOBJECTNTHANDLEFROMNAME"
+                   << std::endl;
+
+    testing::internal::CaptureStdout();
+    GdiLogging::logEnter<D3DKMT_OPENSYNCOBJECTNTHANDLEFROMNAME *>(&param);
+    std::string logEnterStr = testing::internal::GetCapturedStdout();
+    EXPECT_STREQ(expectedOutput.str().c_str(), logEnterStr.c_str());
+
+    expectedOutput.str(std::string());
+    expectedOutput << logExitBegin
+                   << std::hex << status
+                   << " " << std::endl;
+
+    testing::internal::CaptureStdout();
+    GdiLogging::logExit<D3DKMT_OPENSYNCOBJECTNTHANDLEFROMNAME *>(status, &param);
+    std::string logExitStr = testing::internal::GetCapturedStdout();
+    EXPECT_STREQ(expectedOutput.str().c_str(), logExitStr.c_str());
+}
+
 TEST_F(GdiInterfaceLoggingTest, WhenGdiLoggingIsEnabledWhenLoggingDestroyAllocation2ThenExpectCorrectStrings) {
     D3DKMT_DESTROYALLOCATION2 param = {};
     param.Flags.SynchronousDestroy = 1;
