@@ -606,6 +606,10 @@ TEST(DrmBufferObject, givenDrmWhenBindOperationFailsThenFenceValueNotGrow) {
 }
 
 TEST(DrmBufferObject, givenDrmWhenBindOperationSucceedsThenFenceValueGrow) {
+
+    DebugManagerStateRestore restorer;
+    debugManager.flags.EnableWaitOnUserFenceAfterBindAndUnbind.set(1);
+
     auto executionEnvironment = new ExecutionEnvironment;
     executionEnvironment->setDebuggingMode(NEO::DebuggingMode::online);
     executionEnvironment->prepareRootDeviceEnvironments(1);
@@ -636,26 +640,19 @@ TEST(DrmBufferObject, givenDrmWhenBindOperationSucceedsThenFenceValueGrow) {
     EXPECT_EQ(drm->fenceVal[0], initFenceValue + 1);
 }
 
-TEST(DrmBufferObject, givenDrmWhenBindOperationSucceedsWithForcePagingFenceThenFenceValueGrow) {
+using ::testing::Combine;
+using ::testing::Values;
+using ::testing::WithParamInterface;
+
+class DrmBufferObjectBindTestWithForcePagingFenceSucceeds : public ::testing::TestWithParam<std::tuple<int32_t, bool, bool>> {};
+
+TEST_P(DrmBufferObjectBindTestWithForcePagingFenceSucceeds, givenDrmWhenBindOperationSucceedsWithForcePagingFenceThenFenceValueGrow) {
+    int32_t waitOnUserFenceAfterBindAndUnbindVal = std::get<0>(GetParam());
+    bool isVMBindImmediateSupportedVal = std::get<1>(GetParam());
+    bool isWaitBeforeBindRequiredResultVal = std::get<2>(GetParam());
 
     DebugManagerStateRestore restorer;
-    debugManager.flags.EnableWaitOnUserFenceAfterBindAndUnbind.set(1);
-
-    class MockOsContextLinuxUnbind : public OsContextLinux {
-      public:
-        using OsContextLinux::drmContextIds;
-        using OsContextLinux::fenceVal;
-        using OsContextLinux::pagingFence;
-
-        MockOsContextLinuxUnbind(Drm &drm, uint32_t rootDeviceIndex, uint32_t contextId, const EngineDescriptor &engineDescriptor)
-            : OsContextLinux(drm, rootDeviceIndex, contextId, engineDescriptor) {}
-
-        void waitForPagingFenceGivenFenceVal(uint64_t fenceValToWait) override {
-            waitForPagingFenceGivenFenceValCalled = true;
-        }
-
-        bool waitForPagingFenceGivenFenceValCalled = false;
-    };
+    debugManager.flags.EnableWaitOnUserFenceAfterBindAndUnbind.set(waitOnUserFenceAfterBindAndUnbindVal);
 
     auto executionEnvironment = new ExecutionEnvironment;
     executionEnvironment->setDebuggingMode(NEO::DebuggingMode::online);
@@ -664,14 +661,28 @@ TEST(DrmBufferObject, givenDrmWhenBindOperationSucceedsWithForcePagingFenceThenF
     executionEnvironment->rootDeviceEnvironments[0]->initGmm();
     executionEnvironment->rootDeviceEnvironments[0]->osInterface = std::make_unique<OSInterface>();
 
-    auto drm = new DrmMock(*executionEnvironment->rootDeviceEnvironments[0]);
+    class MockDrmWithWaitUserFence : public DrmMock {
+      public:
+        MockDrmWithWaitUserFence(RootDeviceEnvironment &rootDeviceEnvironment)
+            : DrmMock(rootDeviceEnvironment), waitUserFenceCalled(false) {}
+
+        int waitUserFence(uint32_t ctxId, uint64_t address, uint64_t value, ValueWidth dataWidth, int64_t timeout, uint16_t flags, bool userInterrupt,
+                          uint32_t externalInterruptId, GraphicsAllocation *allocForInterruptWait) override {
+            waitUserFenceCalled = true;
+            return 0;
+        }
+
+        bool waitUserFenceCalled;
+    };
+
+    auto drm = new MockDrmWithWaitUserFence(*executionEnvironment->rootDeviceEnvironments[0]);
     drm->requirePerContextVM = false;
-    drm->isVMBindImmediateSupported = true;
+    drm->isVMBindImmediateSupported = isVMBindImmediateSupportedVal;
     auto ioctlHelper = std::make_unique<MockIoctlHelper>(*drm);
-    ioctlHelper->isWaitBeforeBindRequiredResult = true;
+    ioctlHelper->isWaitBeforeBindRequiredResult = isWaitBeforeBindRequiredResultVal;
     drm->ioctlHelper.reset(ioctlHelper.release());
 
-    auto osContext = new MockOsContextLinuxUnbind(*drm, 0, 0u, EngineDescriptorHelper::getDefaultDescriptor());
+    auto osContext = new OsContextLinux(*drm, 0, 0u, EngineDescriptorHelper::getDefaultDescriptor());
     osContext->ensureContextInitialized(false);
 
     executionEnvironment->rootDeviceEnvironments[0]->osInterface->setDriverModel(std::unique_ptr<DriverModel>(drm));
@@ -689,30 +700,27 @@ TEST(DrmBufferObject, givenDrmWhenBindOperationSucceedsWithForcePagingFenceThenF
     drm->bindBufferObject(osContext, 0, &bo, true);
 
     EXPECT_EQ(drm->fenceVal[0], initFenceValue + 1);
-    EXPECT_TRUE(osContext->waitForPagingFenceGivenFenceValCalled);
+    EXPECT_TRUE(drm->waitUserFenceCalled);
     delete osContext;
 }
 
-TEST(DrmBufferObject, givenDrmWhenBindOperationSucceedsWithForcePagingFenceNotWaitOnUserFenceAfterBindAndUnbindThenFenceValueGrow) {
+INSTANTIATE_TEST_SUITE_P(
+    DrmBufferObjectBindTestsWithForcePagingFenceSucceeds,
+    DrmBufferObjectBindTestWithForcePagingFenceSucceeds,
+    Combine(
+        Values(0, 1),
+        Values(true, false),
+        Values(true, false)));
+
+class DrmBufferObjectBindTestWithForcePagingFenceFalseWaitUserFenceNotCalled : public ::testing::TestWithParam<std::tuple<int32_t, bool, bool>> {};
+
+TEST_P(DrmBufferObjectBindTestWithForcePagingFenceFalseWaitUserFenceNotCalled, givenDrmWhenBindOperationSucceedsWithForcePagingFenceFalseThenFenceValueDoesNotGrow) {
+    int32_t waitOnUserFenceAfterBindAndUnbindVal = std::get<0>(GetParam());
+    bool isVMBindImmediateSupportedVal = std::get<1>(GetParam());
+    bool isWaitBeforeBindRequiredResultVal = std::get<2>(GetParam());
 
     DebugManagerStateRestore restorer;
-    debugManager.flags.EnableWaitOnUserFenceAfterBindAndUnbind.set(0);
-
-    class MockOsContextLinuxUnbind : public OsContextLinux {
-      public:
-        using OsContextLinux::drmContextIds;
-        using OsContextLinux::fenceVal;
-        using OsContextLinux::pagingFence;
-
-        MockOsContextLinuxUnbind(Drm &drm, uint32_t rootDeviceIndex, uint32_t contextId, const EngineDescriptor &engineDescriptor)
-            : OsContextLinux(drm, rootDeviceIndex, contextId, engineDescriptor) {}
-
-        void waitForPagingFenceGivenFenceVal(uint64_t fenceValToWait) override {
-            waitForPagingFenceGivenFenceValCalled = true;
-        }
-
-        bool waitForPagingFenceGivenFenceValCalled = false;
-    };
+    debugManager.flags.EnableWaitOnUserFenceAfterBindAndUnbind.set(waitOnUserFenceAfterBindAndUnbindVal);
 
     auto executionEnvironment = new ExecutionEnvironment;
     executionEnvironment->setDebuggingMode(NEO::DebuggingMode::online);
@@ -721,14 +729,28 @@ TEST(DrmBufferObject, givenDrmWhenBindOperationSucceedsWithForcePagingFenceNotWa
     executionEnvironment->rootDeviceEnvironments[0]->initGmm();
     executionEnvironment->rootDeviceEnvironments[0]->osInterface = std::make_unique<OSInterface>();
 
-    auto drm = new DrmMock(*executionEnvironment->rootDeviceEnvironments[0]);
+    class MockDrmWithWaitUserFence : public DrmMock {
+      public:
+        MockDrmWithWaitUserFence(RootDeviceEnvironment &rootDeviceEnvironment)
+            : DrmMock(rootDeviceEnvironment), waitUserFenceCalled(false) {}
+
+        int waitUserFence(uint32_t ctxId, uint64_t address, uint64_t value, ValueWidth dataWidth, int64_t timeout, uint16_t flags, bool userInterrupt,
+                          uint32_t externalInterruptId, GraphicsAllocation *allocForInterruptWait) override {
+            waitUserFenceCalled = true;
+            return 0;
+        }
+
+        bool waitUserFenceCalled;
+    };
+
+    auto drm = new MockDrmWithWaitUserFence(*executionEnvironment->rootDeviceEnvironments[0]);
     drm->requirePerContextVM = false;
-    drm->isVMBindImmediateSupported = true;
+    drm->isVMBindImmediateSupported = isVMBindImmediateSupportedVal;
     auto ioctlHelper = std::make_unique<MockIoctlHelper>(*drm);
-    ioctlHelper->isWaitBeforeBindRequiredResult = true;
+    ioctlHelper->isWaitBeforeBindRequiredResult = isWaitBeforeBindRequiredResultVal;
     drm->ioctlHelper.reset(ioctlHelper.release());
 
-    auto osContext = new MockOsContextLinuxUnbind(*drm, 0, 0u, EngineDescriptorHelper::getDefaultDescriptor());
+    auto osContext = new OsContextLinux(*drm, 0, 0u, EngineDescriptorHelper::getDefaultDescriptor());
     osContext->ensureContextInitialized(false);
 
     executionEnvironment->rootDeviceEnvironments[0]->osInterface->setDriverModel(std::unique_ptr<DriverModel>(drm));
@@ -743,92 +765,29 @@ TEST(DrmBufferObject, givenDrmWhenBindOperationSucceedsWithForcePagingFenceNotWa
     auto osContextCount = engines.size();
 
     MockBufferObject bo(device->getRootDeviceIndex(), drm, 3, 0, 0, osContextCount);
-    drm->bindBufferObject(osContext, 0, &bo, true);
+    drm->bindBufferObject(osContext, 0, &bo, false);
 
-    EXPECT_EQ(drm->fenceVal[0], initFenceValue + 1);
-    EXPECT_TRUE(osContext->waitForPagingFenceGivenFenceValCalled);
+    EXPECT_EQ(drm->fenceVal[0], initFenceValue);
+    EXPECT_FALSE(drm->waitUserFenceCalled);
     delete osContext;
 }
 
-TEST(DrmBufferObject, givenDrmWhenBindOperationSucceedsWithForcePagingFenceWithWaitOnUserFenceAfterBindAndUnbindAndNotUseVMBindImmediateThenFenceValueGrow) {
-
-    DebugManagerStateRestore restorer;
-    debugManager.flags.EnableWaitOnUserFenceAfterBindAndUnbind.set(1);
-
-    class MockOsContextLinuxUnbind : public OsContextLinux {
-      public:
-        using OsContextLinux::drmContextIds;
-        using OsContextLinux::fenceVal;
-        using OsContextLinux::pagingFence;
-
-        MockOsContextLinuxUnbind(Drm &drm, uint32_t rootDeviceIndex, uint32_t contextId, const EngineDescriptor &engineDescriptor)
-            : OsContextLinux(drm, rootDeviceIndex, contextId, engineDescriptor) {}
-
-        void waitForPagingFenceGivenFenceVal(uint64_t fenceValToWait) override {
-            waitForPagingFenceGivenFenceValCalled = true;
-        }
-
-        bool waitForPagingFenceGivenFenceValCalled = false;
-    };
-
-    auto executionEnvironment = new ExecutionEnvironment;
-    executionEnvironment->setDebuggingMode(NEO::DebuggingMode::online);
-    executionEnvironment->prepareRootDeviceEnvironments(1);
-    executionEnvironment->rootDeviceEnvironments[0]->setHwInfoAndInitHelpers(defaultHwInfo.get());
-    executionEnvironment->rootDeviceEnvironments[0]->initGmm();
-    executionEnvironment->rootDeviceEnvironments[0]->osInterface = std::make_unique<OSInterface>();
-
-    auto drm = new DrmMock(*executionEnvironment->rootDeviceEnvironments[0]);
-    drm->requirePerContextVM = false;
-    // Making the useVMBindImmediate() false
-    drm->isVMBindImmediateSupported = false;
-    auto ioctlHelper = std::make_unique<MockIoctlHelper>(*drm);
-    ioctlHelper->isWaitBeforeBindRequiredResult = true;
-    drm->ioctlHelper.reset(ioctlHelper.release());
-
-    auto osContext = new MockOsContextLinuxUnbind(*drm, 0, 0u, EngineDescriptorHelper::getDefaultDescriptor());
-    osContext->ensureContextInitialized(false);
-
-    executionEnvironment->rootDeviceEnvironments[0]->osInterface->setDriverModel(std::unique_ptr<DriverModel>(drm));
-    executionEnvironment->rootDeviceEnvironments[0]->memoryOperationsInterface = DrmMemoryOperationsHandler::create(*drm, 0u, false);
-    // Make sure to disable the debugging mode
-    executionEnvironment->setDebuggingMode(DebuggingMode::disabled);
-    uint64_t initFenceValue = 10u;
-    drm->fenceVal[0] = initFenceValue;
-    std::unique_ptr<Device> device(MockDevice::createWithExecutionEnvironment<MockDevice>(defaultHwInfo.get(), executionEnvironment, 0));
-
-    auto &engines = device->getExecutionEnvironment()->memoryManager->getRegisteredEngines(device->getRootDeviceIndex());
-    auto osContextCount = engines.size();
-
-    MockBufferObject bo(device->getRootDeviceIndex(), drm, 3, 0, 0, osContextCount);
-    drm->bindBufferObject(osContext, 0, &bo, true);
-
-    EXPECT_EQ(drm->fenceVal[0], initFenceValue + 1);
-    EXPECT_TRUE(osContext->waitForPagingFenceGivenFenceValCalled);
-    delete osContext;
-}
+INSTANTIATE_TEST_SUITE_P(
+    DrmBufferObjectBindTestsWithForcePagingFenceFalseWaitUserFenceNotCalled,
+    DrmBufferObjectBindTestWithForcePagingFenceFalseWaitUserFenceNotCalled,
+    Values(
+        std::make_tuple(0, true, false),
+        std::make_tuple(0, false, false),
+        std::make_tuple(0, false, true),
+        std::make_tuple(1, true, false),
+        std::make_tuple(1, false, false),
+        std::make_tuple(1, false, true)));
 
 TEST(DrmBufferObject, givenDrmWhenBindOperationSucceedsWithForcePagingFenceWithDebuggingEnabledWithWaitOnUserFenceAfterBindAndUnbindAndNotUseVMBindImmediateThenFenceValueDoesNotGrow) {
 
     DebugManagerStateRestore restorer;
     debugManager.flags.EnableWaitOnUserFenceAfterBindAndUnbind.set(1);
 
-    class MockOsContextLinuxUnbind : public OsContextLinux {
-      public:
-        using OsContextLinux::drmContextIds;
-        using OsContextLinux::fenceVal;
-        using OsContextLinux::pagingFence;
-
-        MockOsContextLinuxUnbind(Drm &drm, uint32_t rootDeviceIndex, uint32_t contextId, const EngineDescriptor &engineDescriptor)
-            : OsContextLinux(drm, rootDeviceIndex, contextId, engineDescriptor) {}
-
-        void waitForPagingFenceGivenFenceVal(uint64_t fenceValToWait) override {
-            waitForPagingFenceGivenFenceValCalled = true;
-        }
-
-        bool waitForPagingFenceGivenFenceValCalled = false;
-    };
-
     auto executionEnvironment = new ExecutionEnvironment;
     executionEnvironment->setDebuggingMode(NEO::DebuggingMode::online);
     executionEnvironment->prepareRootDeviceEnvironments(1);
@@ -836,7 +795,21 @@ TEST(DrmBufferObject, givenDrmWhenBindOperationSucceedsWithForcePagingFenceWithD
     executionEnvironment->rootDeviceEnvironments[0]->initGmm();
     executionEnvironment->rootDeviceEnvironments[0]->osInterface = std::make_unique<OSInterface>();
 
-    auto drm = new DrmMock(*executionEnvironment->rootDeviceEnvironments[0]);
+    class MockDrmWithWaitUserFence : public DrmMock {
+      public:
+        MockDrmWithWaitUserFence(RootDeviceEnvironment &rootDeviceEnvironment)
+            : DrmMock(rootDeviceEnvironment), waitUserFenceCalled(false) {}
+
+        int waitUserFence(uint32_t ctxId, uint64_t address, uint64_t value, ValueWidth dataWidth, int64_t timeout, uint16_t flags, bool userInterrupt,
+                          uint32_t externalInterruptId, GraphicsAllocation *allocForInterruptWait) override {
+            waitUserFenceCalled = true;
+            return 0;
+        }
+
+        bool waitUserFenceCalled;
+    };
+
+    auto drm = new MockDrmWithWaitUserFence(*executionEnvironment->rootDeviceEnvironments[0]);
     drm->requirePerContextVM = false;
     // Making the useVMBindImmediate() false
     drm->isVMBindImmediateSupported = false;
@@ -844,7 +817,7 @@ TEST(DrmBufferObject, givenDrmWhenBindOperationSucceedsWithForcePagingFenceWithD
     ioctlHelper->isWaitBeforeBindRequiredResult = true;
     drm->ioctlHelper.reset(ioctlHelper.release());
 
-    auto osContext = new MockOsContextLinuxUnbind(*drm, 0, 0u, EngineDescriptorHelper::getDefaultDescriptor());
+    auto osContext = new OsContextLinux(*drm, 0, 0u, EngineDescriptorHelper::getDefaultDescriptor());
     osContext->ensureContextInitialized(false);
 
     executionEnvironment->rootDeviceEnvironments[0]->osInterface->setDriverModel(std::unique_ptr<DriverModel>(drm));
@@ -862,65 +835,7 @@ TEST(DrmBufferObject, givenDrmWhenBindOperationSucceedsWithForcePagingFenceWithD
     drm->bindBufferObject(osContext, 0, &bo, true);
 
     EXPECT_EQ(drm->fenceVal[0], initFenceValue);
-    EXPECT_FALSE(osContext->waitForPagingFenceGivenFenceValCalled);
-    delete osContext;
-}
-
-TEST(DrmBufferObject, givenDrmWhenBindOperationSucceedsWithForcePagingFenceNotWaitOnUserFenceAfterBindAndUnbindAndNotUseVMBindImmediateThenFenceValueGrow) {
-
-    DebugManagerStateRestore restorer;
-    debugManager.flags.EnableWaitOnUserFenceAfterBindAndUnbind.set(0);
-
-    class MockOsContextLinuxUnbind : public OsContextLinux {
-      public:
-        using OsContextLinux::drmContextIds;
-        using OsContextLinux::fenceVal;
-        using OsContextLinux::pagingFence;
-
-        MockOsContextLinuxUnbind(Drm &drm, uint32_t rootDeviceIndex, uint32_t contextId, const EngineDescriptor &engineDescriptor)
-            : OsContextLinux(drm, rootDeviceIndex, contextId, engineDescriptor) {}
-
-        void waitForPagingFenceGivenFenceVal(uint64_t fenceValToWait) override {
-            waitForPagingFenceGivenFenceValCalled = true;
-        }
-
-        bool waitForPagingFenceGivenFenceValCalled = false;
-    };
-
-    auto executionEnvironment = new ExecutionEnvironment;
-    executionEnvironment->setDebuggingMode(NEO::DebuggingMode::online);
-    executionEnvironment->prepareRootDeviceEnvironments(1);
-    executionEnvironment->rootDeviceEnvironments[0]->setHwInfoAndInitHelpers(defaultHwInfo.get());
-    executionEnvironment->rootDeviceEnvironments[0]->initGmm();
-    executionEnvironment->rootDeviceEnvironments[0]->osInterface = std::make_unique<OSInterface>();
-
-    auto drm = new DrmMock(*executionEnvironment->rootDeviceEnvironments[0]);
-    drm->requirePerContextVM = false;
-    // Making the useVMBindImmediate() false
-    drm->isVMBindImmediateSupported = false;
-    auto ioctlHelper = std::make_unique<MockIoctlHelper>(*drm);
-    ioctlHelper->isWaitBeforeBindRequiredResult = true;
-    drm->ioctlHelper.reset(ioctlHelper.release());
-
-    auto osContext = new MockOsContextLinuxUnbind(*drm, 0, 0u, EngineDescriptorHelper::getDefaultDescriptor());
-    osContext->ensureContextInitialized(false);
-
-    executionEnvironment->rootDeviceEnvironments[0]->osInterface->setDriverModel(std::unique_ptr<DriverModel>(drm));
-    executionEnvironment->rootDeviceEnvironments[0]->memoryOperationsInterface = DrmMemoryOperationsHandler::create(*drm, 0u, false);
-    // Make sure to disable the debugging mode
-    executionEnvironment->setDebuggingMode(DebuggingMode::disabled);
-    uint64_t initFenceValue = 10u;
-    drm->fenceVal[0] = initFenceValue;
-    std::unique_ptr<Device> device(MockDevice::createWithExecutionEnvironment<MockDevice>(defaultHwInfo.get(), executionEnvironment, 0));
-
-    auto &engines = device->getExecutionEnvironment()->memoryManager->getRegisteredEngines(device->getRootDeviceIndex());
-    auto osContextCount = engines.size();
-
-    MockBufferObject bo(device->getRootDeviceIndex(), drm, 3, 0, 0, osContextCount);
-    drm->bindBufferObject(osContext, 0, &bo, true);
-
-    EXPECT_EQ(drm->fenceVal[0], initFenceValue + 1);
-    EXPECT_TRUE(osContext->waitForPagingFenceGivenFenceValCalled);
+    EXPECT_FALSE(drm->waitUserFenceCalled);
     delete osContext;
 }
 
@@ -1027,22 +942,6 @@ TEST(DrmBufferObject, givenDrmWhenUnBindOperationSucceedsAndForceFenceWaitThenFe
     debugManager.flags.EnableUserFenceUponUnbind.set(1);
     debugManager.flags.EnableWaitOnUserFenceAfterBindAndUnbind.set(1);
 
-    class MockOsContextLinuxUnbind : public OsContextLinux {
-      public:
-        using OsContextLinux::drmContextIds;
-        using OsContextLinux::fenceVal;
-        using OsContextLinux::pagingFence;
-
-        MockOsContextLinuxUnbind(Drm &drm, uint32_t rootDeviceIndex, uint32_t contextId, const EngineDescriptor &engineDescriptor)
-            : OsContextLinux(drm, rootDeviceIndex, contextId, engineDescriptor) {}
-
-        void waitForPagingFenceGivenFenceVal(uint64_t fenceValToWait) override {
-            waitForPagingFenceGivenFenceValCalled = true;
-        }
-
-        bool waitForPagingFenceGivenFenceValCalled = false;
-    };
-
     auto executionEnvironment = new ExecutionEnvironment;
     executionEnvironment->setDebuggingMode(NEO::DebuggingMode::online);
     executionEnvironment->prepareRootDeviceEnvironments(1);
@@ -1050,14 +949,28 @@ TEST(DrmBufferObject, givenDrmWhenUnBindOperationSucceedsAndForceFenceWaitThenFe
     executionEnvironment->rootDeviceEnvironments[0]->initGmm();
     executionEnvironment->rootDeviceEnvironments[0]->osInterface = std::make_unique<OSInterface>();
 
-    auto drm = new DrmMock(*executionEnvironment->rootDeviceEnvironments[0]);
+    class MockDrmWithWaitUserFence : public DrmMock {
+      public:
+        MockDrmWithWaitUserFence(RootDeviceEnvironment &rootDeviceEnvironment)
+            : DrmMock(rootDeviceEnvironment), waitUserFenceCalled(false) {}
+
+        int waitUserFence(uint32_t ctxId, uint64_t address, uint64_t value, ValueWidth dataWidth, int64_t timeout, uint16_t flags, bool userInterrupt,
+                          uint32_t externalInterruptId, GraphicsAllocation *allocForInterruptWait) override {
+            waitUserFenceCalled = true;
+            return 0;
+        }
+
+        bool waitUserFenceCalled;
+    };
+
+    auto drm = new MockDrmWithWaitUserFence(*executionEnvironment->rootDeviceEnvironments[0]);
     drm->requirePerContextVM = false;
     drm->isVMBindImmediateSupported = true;
     auto ioctlHelper = std::make_unique<MockIoctlHelper>(*drm);
     ioctlHelper->isWaitBeforeBindRequiredResult = true;
     drm->ioctlHelper.reset(ioctlHelper.release());
 
-    auto osContext = new MockOsContextLinuxUnbind(*drm, 0, 0u, EngineDescriptorHelper::getDefaultDescriptor());
+    auto osContext = new OsContextLinux(*drm, 0, 0u, EngineDescriptorHelper::getDefaultDescriptor());
     osContext->ensureContextInitialized(false);
 
     executionEnvironment->rootDeviceEnvironments[0]->osInterface->setDriverModel(std::unique_ptr<DriverModel>(drm));
@@ -1073,7 +986,7 @@ TEST(DrmBufferObject, givenDrmWhenUnBindOperationSucceedsAndForceFenceWaitThenFe
     drm->unbindBufferObject(static_cast<OsContext *>(osContext), 0, &bo);
 
     EXPECT_EQ(drm->fenceVal[0], initFenceValue + 1);
-    EXPECT_TRUE(osContext->waitForPagingFenceGivenFenceValCalled);
+    EXPECT_TRUE(drm->waitUserFenceCalled);
     delete osContext;
 }
 
@@ -1082,22 +995,6 @@ TEST(DrmBufferObject, givenDrmWhenUnBindOperationSucceedsWaitBeforeBindFalseAndF
     debugManager.flags.EnableUserFenceUponUnbind.set(0);
     debugManager.flags.EnableWaitOnUserFenceAfterBindAndUnbind.set(1);
 
-    class MockOsContextLinuxUnbind : public OsContextLinux {
-      public:
-        using OsContextLinux::drmContextIds;
-        using OsContextLinux::fenceVal;
-        using OsContextLinux::pagingFence;
-
-        MockOsContextLinuxUnbind(Drm &drm, uint32_t rootDeviceIndex, uint32_t contextId, const EngineDescriptor &engineDescriptor)
-            : OsContextLinux(drm, rootDeviceIndex, contextId, engineDescriptor) {}
-
-        void waitForPagingFenceGivenFenceVal(uint64_t fenceValToWait) override {
-            waitForPagingFenceGivenFenceValCalled = true;
-        }
-
-        bool waitForPagingFenceGivenFenceValCalled = false;
-    };
-
     auto executionEnvironment = new ExecutionEnvironment;
     executionEnvironment->setDebuggingMode(NEO::DebuggingMode::online);
     executionEnvironment->prepareRootDeviceEnvironments(1);
@@ -1105,14 +1002,28 @@ TEST(DrmBufferObject, givenDrmWhenUnBindOperationSucceedsWaitBeforeBindFalseAndF
     executionEnvironment->rootDeviceEnvironments[0]->initGmm();
     executionEnvironment->rootDeviceEnvironments[0]->osInterface = std::make_unique<OSInterface>();
 
-    auto drm = new DrmMock(*executionEnvironment->rootDeviceEnvironments[0]);
+    class MockDrmWithWaitUserFence : public DrmMock {
+      public:
+        MockDrmWithWaitUserFence(RootDeviceEnvironment &rootDeviceEnvironment)
+            : DrmMock(rootDeviceEnvironment), waitUserFenceCalled(false) {}
+
+        int waitUserFence(uint32_t ctxId, uint64_t address, uint64_t value, ValueWidth dataWidth, int64_t timeout, uint16_t flags, bool userInterrupt,
+                          uint32_t externalInterruptId, GraphicsAllocation *allocForInterruptWait) override {
+            waitUserFenceCalled = true;
+            return 0;
+        }
+
+        bool waitUserFenceCalled;
+    };
+
+    auto drm = new MockDrmWithWaitUserFence(*executionEnvironment->rootDeviceEnvironments[0]);
     drm->requirePerContextVM = false;
     drm->isVMBindImmediateSupported = true;
     auto ioctlHelper = std::make_unique<MockIoctlHelper>(*drm);
     ioctlHelper->isWaitBeforeBindRequiredResult = false;
     drm->ioctlHelper.reset(ioctlHelper.release());
 
-    auto osContext = new MockOsContextLinuxUnbind(*drm, 0, 0u, EngineDescriptorHelper::getDefaultDescriptor());
+    auto osContext = new OsContextLinux(*drm, 0, 0u, EngineDescriptorHelper::getDefaultDescriptor());
     osContext->ensureContextInitialized(false);
 
     executionEnvironment->rootDeviceEnvironments[0]->osInterface->setDriverModel(std::unique_ptr<DriverModel>(drm));
@@ -1128,31 +1039,15 @@ TEST(DrmBufferObject, givenDrmWhenUnBindOperationSucceedsWaitBeforeBindFalseAndF
     drm->unbindBufferObject(static_cast<OsContext *>(osContext), 0, &bo);
 
     EXPECT_EQ(drm->fenceVal[0], initFenceValue);
-    EXPECT_FALSE(osContext->waitForPagingFenceGivenFenceValCalled);
+    EXPECT_FALSE(drm->waitUserFenceCalled);
     delete osContext;
 }
 
-TEST(DrmBufferObject, givenDrmWhenUnBindOperationSucceedsWaitBeforeBindTrueAndForceFenceWaitButNotVmBindImmediateThenWaitPagingFenceNotCalled) {
+TEST(DrmBufferObject, givenDrmWhenUnBindOperationSucceedsWaitBeforeBindTrueAndForceFenceWaitButNotVmBindImmediateThenWaitUserFenceNotCalled) {
     DebugManagerStateRestore restorer;
     debugManager.flags.EnableUserFenceUponUnbind.set(1);
     debugManager.flags.EnableWaitOnUserFenceAfterBindAndUnbind.set(1);
 
-    class MockOsContextLinuxUnbind : public OsContextLinux {
-      public:
-        using OsContextLinux::drmContextIds;
-        using OsContextLinux::fenceVal;
-        using OsContextLinux::pagingFence;
-
-        MockOsContextLinuxUnbind(Drm &drm, uint32_t rootDeviceIndex, uint32_t contextId, const EngineDescriptor &engineDescriptor)
-            : OsContextLinux(drm, rootDeviceIndex, contextId, engineDescriptor) {}
-
-        void waitForPagingFenceGivenFenceVal(uint64_t fenceValToWait) override {
-            waitForPagingFenceGivenFenceValCalled = true;
-        }
-
-        bool waitForPagingFenceGivenFenceValCalled = false;
-    };
-
     auto executionEnvironment = new ExecutionEnvironment;
     executionEnvironment->setDebuggingMode(NEO::DebuggingMode::online);
     executionEnvironment->prepareRootDeviceEnvironments(1);
@@ -1160,14 +1055,28 @@ TEST(DrmBufferObject, givenDrmWhenUnBindOperationSucceedsWaitBeforeBindTrueAndFo
     executionEnvironment->rootDeviceEnvironments[0]->initGmm();
     executionEnvironment->rootDeviceEnvironments[0]->osInterface = std::make_unique<OSInterface>();
 
-    auto drm = new DrmMock(*executionEnvironment->rootDeviceEnvironments[0]);
+    class MockDrmWithWaitUserFence : public DrmMock {
+      public:
+        MockDrmWithWaitUserFence(RootDeviceEnvironment &rootDeviceEnvironment)
+            : DrmMock(rootDeviceEnvironment), waitUserFenceCalled(false) {}
+
+        int waitUserFence(uint32_t ctxId, uint64_t address, uint64_t value, ValueWidth dataWidth, int64_t timeout, uint16_t flags, bool userInterrupt,
+                          uint32_t externalInterruptId, GraphicsAllocation *allocForInterruptWait) override {
+            waitUserFenceCalled = true;
+            return 0;
+        }
+
+        bool waitUserFenceCalled;
+    };
+
+    auto drm = new MockDrmWithWaitUserFence(*executionEnvironment->rootDeviceEnvironments[0]);
     drm->requirePerContextVM = false;
     drm->isVMBindImmediateSupported = false;
     auto ioctlHelper = std::make_unique<MockIoctlHelper>(*drm);
     ioctlHelper->isWaitBeforeBindRequiredResult = true;
     drm->ioctlHelper.reset(ioctlHelper.release());
 
-    auto osContext = new MockOsContextLinuxUnbind(*drm, 0, 0u, EngineDescriptorHelper::getDefaultDescriptor());
+    auto osContext = new OsContextLinux(*drm, 0, 0u, EngineDescriptorHelper::getDefaultDescriptor());
     osContext->ensureContextInitialized(false);
 
     executionEnvironment->rootDeviceEnvironments[0]->osInterface->setDriverModel(std::unique_ptr<DriverModel>(drm));
@@ -1183,7 +1092,7 @@ TEST(DrmBufferObject, givenDrmWhenUnBindOperationSucceedsWaitBeforeBindTrueAndFo
     drm->unbindBufferObject(static_cast<OsContext *>(osContext), 0, &bo);
 
     EXPECT_EQ(drm->fenceVal[0], initFenceValue);
-    EXPECT_FALSE(osContext->waitForPagingFenceGivenFenceValCalled);
+    EXPECT_FALSE(drm->waitUserFenceCalled);
     delete osContext;
 }
 
