@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2020-2023 Intel Corporation
+ * Copyright (C) 2020-2024 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -12,9 +12,7 @@
 #include "shared/source/os_interface/linux/i915.h"
 #include "shared/test/common/helpers/default_hw_info.h"
 #include "shared/test/common/libult/linux/drm_mock.h"
-
-#include "gtest/gtest.h"
-#include "test_traits_common.h"
+#include "shared/test/common/test_macros/hw_test.h"
 
 using namespace NEO;
 
@@ -46,7 +44,7 @@ class DrmTipMock : public DrmMock {
     }
 
     int handleRemainingRequests(DrmIoctl request, void *arg) override {
-        if ((request == DrmIoctl::Query) && (arg != nullptr)) {
+        if ((request == DrmIoctl::query) && (arg != nullptr)) {
             if (i915QuerySuccessCount == 0) {
                 return EINVAL;
             }
@@ -59,7 +57,7 @@ class DrmTipMock : public DrmMock {
                 handleQueryItem(reinterpret_cast<QueryItem *>(query->itemsPtr) + i);
             }
             return 0;
-        } else if (request == DrmIoctl::GemMmapOffset) {
+        } else if (request == DrmIoctl::gemMmapOffset) {
             auto mmapArg = static_cast<GemMmapOffset *>(arg);
             mmapOffsetFlagsReceived = mmapArg->flags;
             mmapArg->offset = offset;
@@ -98,7 +96,7 @@ class DrmTipMock : public DrmMock {
     }
 
     virtual int handleKernelSpecificRequests(DrmIoctl request, void *arg) {
-        if (request == DrmIoctl::GemCreateExt) {
+        if (request == DrmIoctl::gemCreateExt) {
             auto createExtParams = static_cast<drm_i915_gem_create_ext *>(arg);
             if (createExtParams->size == 0) {
                 return EINVAL;
@@ -129,6 +127,6 @@ struct NonDefaultIoctlsSupported {
         if (productFamily == IGFX_DG1) {
             return true;
         }
-        return TestTraits<NEO::ToGfxCoreFamily<productFamily>::get()>::isUsingNonDefaultIoctls;
+        return IsWithinXeGfxFamily::isMatched<productFamily>();
     }
 };
