@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2021-2024 Intel Corporation
+ * Copyright (C) 2021-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -29,11 +29,11 @@ const char *neoMockSettingsFileName = "neo_mock.config";
 bool CompressionSelector::preferCompressedAllocation(const AllocationProperties &properties) {
     return false;
 }
-void PageFaultManager::transferToCpu(void *ptr, size_t size, void *cmdQ) {
+void CpuPageFaultManager::transferToCpu(void *ptr, size_t size, void *cmdQ) {
 }
-void PageFaultManager::transferToGpu(void *ptr, void *cmdQ) {
+void CpuPageFaultManager::transferToGpu(void *ptr, void *cmdQ) {
 }
-void PageFaultManager::allowCPUMemoryEviction(bool evict, void *ptr, PageFaultData &pageFaultData) {
+void CpuPageFaultManager::allowCPUMemoryEviction(bool evict, void *ptr, PageFaultData &pageFaultData) {
 }
 
 void RootDeviceEnvironment::initApiGfxCoreHelper() {
@@ -63,10 +63,6 @@ void applyWorkarounds() {
     }
 }
 
-bool isPlatformSupported(const HardwareInfo &hwInfoForTests) {
-    return true;
-}
-
 void setupTestFiles(std::string testBinaryFiles, int32_t revId) {
     testBinaryFiles.append("/");
     testBinaryFiles.append(binaryNameSuffix);
