@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2018-2023 Intel Corporation
+ * Copyright (C) 2018-2025 Intel Corporation
  *
  * SPDX-License-Identifier: MIT
  *
@@ -8,6 +8,7 @@
 #include "shared/source/utilities/arrayref.h"
 #include "shared/source/utilities/idlist.h"
 #include "shared/source/utilities/iflist.h"
+#include "shared/source/utilities/lookup_array.h"
 #include "shared/source/utilities/range.h"
 #include "shared/source/utilities/stackvec.h"
 #include "shared/test/unit_test/utilities/containers_tests_helpers.h"
@@ -26,7 +27,7 @@ struct DummyFNode : IFNode<DummyFNode> {
     DummyFNode(uint32_t *destructorsCounter = nullptr)
         : destructorsCounter(destructorsCounter) {
     }
-    ~DummyFNode() {
+    ~DummyFNode() override {
         if (destructorsCounter != nullptr) {
             ++(*destructorsCounter);
         }
@@ -35,7 +36,7 @@ struct DummyFNode : IFNode<DummyFNode> {
     void setPrev(DummyFNode *) {
     }
 
-    uint32_t *destructorsCounter;
+    uint32_t *destructorsCounter = nullptr;
 };
 
 struct DummyDNode : IDNode<DummyDNode> {
@@ -55,8 +56,8 @@ struct DummyDNode : IDNode<DummyDNode> {
     uint32_t *destructorsCounter;
 };
 
-template <typename NodeType = DummyFNode, size_t ArraySize>
-void makeList(NodeType *(&nodes)[ArraySize], uint32_t *destructorsCounter = nullptr) {
+template <typename NodeType = DummyFNode, size_t arraySize>
+void makeList(NodeType *(&nodes)[arraySize], uint32_t *destructorsCounter = nullptr) {
     NodeType *prev = nullptr;
     for (NodeType *&nd : nodes) {
         nd = new NodeType(destructorsCounter);
@@ -178,9 +179,9 @@ TEST(IFNode, WhenVerifingSequenceThenCorrectValueIsReturned) {
     }
 }
 
-template <bool ThreadSafe>
+template <bool threadSafe>
 void iFListTestPushFrontOne() {
-    IFList<DummyFNode, ThreadSafe, false> list;
+    IFList<DummyFNode, threadSafe, false> list;
     ASSERT_TRUE(list.peekIsEmpty());
 
     DummyFNode node1;
@@ -234,9 +235,9 @@ TEST(IFList, WhenSplicingAndDeletingAllThenListIsEmpty) {
     ASSERT_EQ(2 * sizeof(nodes) / sizeof(nodes[0]), destructorCounter);
 }
 
-template <bool ThreadSafe>
+template <bool threadSafe>
 void iFListTestDetachNodes() {
-    IFList<DummyFNode, ThreadSafe, false> list;
+    IFList<DummyFNode, threadSafe, false> list;
 
     uint32_t destructorCounter = 0;
     static const uint32_t maxNodes = 17;
@@ -282,29 +283,35 @@ TEST(IFList, WhenExchangingHeadThenResultIsCorrect) {
     EXPECT_EQ(nullptr, nd2.next);
 }
 
-template <bool ThreadSafe>
+template <bool threadSafe>
 void iFRefListTestPushFrontOne() {
-    auto list = std::unique_ptr<IFRefList<DummyFNode, ThreadSafe, true>>(new IFRefList<DummyFNode, ThreadSafe, true>());
-    ASSERT_TRUE(list->peekIsEmpty());
+    uint32_t destructorCounter = 0;
+    {
+        auto list = std::unique_ptr<IFRefList<DummyFNode, threadSafe, true>>(new IFRefList<DummyFNode, threadSafe, true>());
+        ASSERT_TRUE(list->peekIsEmpty());
 
-    DummyFNode node1;
-    node1.next = nullptr; // garbage
-    list->pushRefFrontOne(node1);
-    ASSERT_FALSE(list->peekIsEmpty());
-    ASSERT_EQ(&node1, list->peekHead()->ref);
-    ASSERT_EQ(nullptr, node1.next);
+        DummyFNode node1(&destructorCounter);
+        node1.next = nullptr; // garbage
+        list->pushRefFrontOne(node1);
+        ASSERT_FALSE(list->peekIsEmpty());
+        ASSERT_EQ(&node1, list->peekHead()->ref);
+        ASSERT_EQ(nullptr, node1.next);
 
-    DummyFNode node2;
-    node2.next = nullptr; // garbage
-    list->pushRefFrontOne(node2);
-    ASSERT_FALSE(list->peekIsEmpty());
-    ASSERT_EQ(&node2, list->peekHead()->ref);
-    ASSERT_EQ(nullptr, node2.next);
+        DummyFNode node2(&destructorCounter);
+        node2.next = nullptr; // garbage
+        list->pushRefFrontOne(node2);
+        ASSERT_FALSE(list->peekIsEmpty());
+        ASSERT_EQ(&node2, list->peekHead()->ref);
+        ASSERT_EQ(nullptr, node2.next);
 
-    ASSERT_EQ(&node2, list->peekHead()->ref);
-    ASSERT_EQ(&node1, list->peekHead()->next->ref);
+        ASSERT_EQ(&node2, list->peekHead()->ref);
+        ASSERT_EQ(&node1, list->peekHead()->next->ref);
 
-    list.reset();
+        EXPECT_EQ(0u, destructorCounter);
+        list.reset();
+        EXPECT_EQ(0u, destructorCounter);
+    }
+    EXPECT_EQ(2u, destructorCounter);
 }
 
 TEST(IFRefList, GivenThreadSafeWhenPushingFrontOneThenResultIsCorrect) {
@@ -496,9 +503,9 @@ TEST(IDNode, WhenVerifyingSequenceThenResultIsCorrect) {
     }
 }
 
-template <bool ThreadSafe>
+template <bool threadSafe>
 void iDListTestPushOne() {
-    IDList<DummyDNode, ThreadSafe, false, false> list(nullptr);
+    IDList<DummyDNode, threadSafe, false, false> list(nullptr);
     ASSERT_TRUE(list.peekIsEmpty());
     ASSERT_EQ(nullptr, list.peekHead());
     ASSERT_EQ(nullptr, list.peekTail());
@@ -589,14 +596,14 @@ TEST(IDList, WhenResettingThenListIsEmpty) {
     ASSERT_EQ(sizeof(nodes) / sizeof(nodes[0]), destructorCounter);
 }
 
-template <bool ThreadSafe>
+template <bool threadSafe>
 void iDListSpliceAndDeleteAll() {
     DummyDNode *nodes[7];
     DummyDNode *nodes2[sizeof(nodes) / sizeof(nodes[0])];
     uint32_t destructorCounter = 0;
     makeList(nodes, &destructorCounter);
     makeList(nodes2, &destructorCounter);
-    IDList<DummyDNode, ThreadSafe, false, false> list;
+    IDList<DummyDNode, threadSafe, false, false> list;
     list.splice(*nodes[0]);
     EXPECT_FALSE(list.peekIsEmpty());
     EXPECT_EQ(nodes[0], list.peekHead());
@@ -627,9 +634,9 @@ TEST(IDList, GivenNonThreadSafeWhenSplicingAndDeletingAllThenResultIsCorrect) {
     iDListSpliceAndDeleteAll<false>();
 }
 
-template <bool ThreadSafe>
+template <bool threadSafe>
 void iDListTestDetachNodes() {
-    IDList<DummyDNode, ThreadSafe, false, false> list;
+    IDList<DummyDNode, threadSafe, false, false> list;
 
     uint32_t destructorCounter = 0;
     static const uint32_t maxNodes = 17;
@@ -653,9 +660,9 @@ TEST(IDList, GivenNonThreadSafeWhenDetachingNodesThenResultIsCorrect) {
     iDListTestDetachNodes<false>();
 }
 
-template <bool ThreadSafe>
+template <bool threadSafe>
 void iDListTestRemoveOne() {
-    IDList<DummyDNode, ThreadSafe, false, false> list;
+    IDList<DummyDNode, threadSafe, false, false> list;
 
     DummyDNode nodes[3];
 
@@ -713,9 +720,9 @@ TEST(IDList, GivenNonThreadSafeWhenRemovingOneThenResultIsCorrect) {
     iDListTestRemoveOne<false>();
 }
 
-template <bool ThreadSafe>
+template <bool threadSafe>
 void iDListTestRemoveFrontOne() {
-    IDList<DummyDNode, ThreadSafe, false, false> list;
+    IDList<DummyDNode, threadSafe, false, false> list;
 
     DummyDNode nodes[3];
     DummyDNode *head = nullptr;
@@ -774,11 +781,11 @@ TEST(IDList, GivenNonThreadSafeWhenRemovingFrontOneThenResultIsCorrect) {
     iDListTestRemoveFrontOne<false>();
 }
 
-template <bool ThreadSafe>
+template <bool threadSafe>
 void iDListTestDetachSequence() {
     DummyDNode *nodes[10];
     makeList(nodes);
-    IDList<DummyDNode, ThreadSafe, false, false> list(nodes[0]);
+    IDList<DummyDNode, threadSafe, false, false> list(nodes[0]);
     DummyDNode *detachedNodes = nullptr;
 
     detachedNodes = list.detachSequence(*nodes[1], *nodes[3]);
@@ -843,9 +850,9 @@ TEST(IDList, GivenNonThreadSafeWhenDetachingSequenceThenResultIsCorrect) {
     iDListTestDetachSequence<false>();
 }
 
-template <bool ThreadSafe>
+template <bool threadSafe>
 void iDListTestPeekContains() {
-    IDList<DummyDNode, ThreadSafe, false, false> list;
+    IDList<DummyDNode, threadSafe, false, false> list;
 
     DummyDNode *node1 = new DummyDNode;
     EXPECT_FALSE(list.peekContains(*node1));
@@ -886,16 +893,16 @@ TEST(IDList, GivenNonThreadSafeWhenPeekingThenResultIsCorrect) {
     iDListTestPeekContains<false>();
 }
 
-template <typename NodeObjectType, bool ThreadSafe, bool OwnsNodes, bool SupportRecursiveLock>
+template <typename NodeObjectType, bool threadSafe, bool ownsNodes, bool supportRecursiveLock>
 void testIDListSpinlock() {
-    struct ListMock : IDList<NodeObjectType, ThreadSafe, OwnsNodes, SupportRecursiveLock> {
+    struct ListMock : IDList<NodeObjectType, threadSafe, ownsNodes, supportRecursiveLock> {
         std::atomic_flag &getLockedRef() { return this->locked; }
         std::atomic<std::thread::id> &getLockOwnerRef() { return this->lockOwner; }
-        using ListenerT = void (*)(IDList<NodeObjectType, ThreadSafe, OwnsNodes, SupportRecursiveLock> &list);
+        using ListenerT = void (*)(IDList<NodeObjectType, threadSafe, ownsNodes, supportRecursiveLock> &list);
         ListenerT &getSpinLockedListenerRef() { return this->spinLockedListener; }
 
         int32_t lockLoopCount = 0;
-        static void listener(IDList<NodeObjectType, ThreadSafe, OwnsNodes, SupportRecursiveLock> &list) {
+        static void listener(IDList<NodeObjectType, threadSafe, ownsNodes, supportRecursiveLock> &list) {
             ListMock &l = reinterpret_cast<ListMock &>(list);
             EXPECT_LT(0, l.lockLoopCount);
             --l.lockLoopCount;
@@ -935,11 +942,11 @@ TEST(IDList, GivenLockedIDListWhenProcessLockedIsUsedThenWaitsInSpinlock) {
     testIDListSpinlock<DummyDNode, true, false, false>();
 }
 
-template <typename NodeObjectType, bool ThreadSafe, bool OwnsNodes, bool SupportRecursiveLock>
+template <typename NodeObjectType, bool threadSafe, bool ownsNodes, bool supportRecursiveLock>
 void testIDListUnlockOnException() {
     using ExType = std::runtime_error;
 
-    struct ListMock : IDList<NodeObjectType, ThreadSafe, OwnsNodes, SupportRecursiveLock> {
+    struct ListMock : IDList<NodeObjectType, threadSafe, ownsNodes, supportRecursiveLock> {
         void throwExFromLock() {
             this->template processLocked<ListMock, &ListMock::throwExFromLockImpl>(nullptr, nullptr);
         }
@@ -963,9 +970,9 @@ TEST(IDList, GivenInsideLockWhenExceptionIsThrownThenUnlocksBeforeRethrowingExce
     testIDListUnlockOnException<DummyDNode, true, false, false>();
 }
 
-template <bool ThreadSafe>
+template <bool threadSafe>
 void iDRefListTestPushFrontOne() {
-    auto list = std::unique_ptr<IDRefList<DummyDNode, ThreadSafe, true>>(new IDRefList<DummyDNode, ThreadSafe, true>());
+    auto list = std::unique_ptr<IDRefList<DummyDNode, threadSafe, true>>(new IDRefList<DummyDNode, threadSafe, true>());
     ASSERT_TRUE(list->peekIsEmpty());
 
     DummyDNode node1;
@@ -1909,3 +1916,56 @@ TEST(ArrayRef, WhenClearedThenEmpty) {
     arrayRefU32.clear();
     EXPECT_TRUE(arrayRefU32.empty());
 }
+
+TEST(LookupArrayFindGreaterEqual, WhenLookingForElementThenReturnFirstThatIsEqualOrGreater) {
+    LookupArray<int, int, 3> arr({{{1, 10}, {4, 40}, {9, 90}}});
+    auto res = arr.findGreaterEqual(0);
+    ASSERT_TRUE(res.has_value());
+    EXPECT_EQ(10, res.value());
+
+    res = arr.findGreaterEqual(1);
+    ASSERT_TRUE(res.has_value());
+    EXPECT_EQ(10, res.value());
+
+    res = arr.findGreaterEqual(2);
+    ASSERT_TRUE(res.has_value());
+    EXPECT_EQ(40, res.value());
+
+    res = arr.findGreaterEqual(3);
+    ASSERT_TRUE(res.has_value());
+    EXPECT_EQ(40, res.value());
+
+    res = arr.findGreaterEqual(4);
+    ASSERT_TRUE(res.has_value());
+    EXPECT_EQ(40, res.value());
+
+    res = arr.findGreaterEqual(9);
+    ASSERT_TRUE(res.has_value());
+    EXPECT_EQ(90, res.value());
+
+    res = arr.findGreaterEqual(10);
+    EXPECT_FALSE(res.has_value());
+}
+
+TEST(LookupArrayLookUpGreaterEqual, WhenLookingForElementThenReturnFirstThatIsEqualOrGreater) {
+    LookupArray<int, int, 3> arr({{{1, 10}, {4, 40}, {9, 90}}});
+    auto res = arr.lookUpGreaterEqual(0);
+    EXPECT_EQ(10, res);
+
+    res = arr.lookUpGreaterEqual(1);
+    EXPECT_EQ(10, res);
+
+    res = arr.lookUpGreaterEqual(2);
+    EXPECT_EQ(40, res);
+
+    res = arr.lookUpGreaterEqual(3);
+    EXPECT_EQ(40, res);
+
+    res = arr.lookUpGreaterEqual(4);
+    EXPECT_EQ(40, res);
+
+    res = arr.lookUpGreaterEqual(9);
+    EXPECT_EQ(90, res);
+
+    EXPECT_THROW(res = arr.lookUpGreaterEqual(10), std::exception);
+}
\ No newline at end of file
